@@ -18,94 +18,73 @@ namespace mozilla {
 
 using namespace dom;
 
-InputData::~InputData()
-{
-}
+InputData::~InputData() {}
 
 InputData::InputData(InputType aInputType)
-  : mInputType(aInputType)
-  , mTime(0)
-  , mFocusSequenceNumber(0)
-  , modifiers(0)
-{
-}
+    : mInputType(aInputType), mTime(0), mFocusSequenceNumber(0), modifiers(0) {}
 
 InputData::InputData(InputType aInputType, uint32_t aTime, TimeStamp aTimeStamp,
                      Modifiers aModifiers)
-  : mInputType(aInputType)
-  , mTime(aTime)
-  , mTimeStamp(aTimeStamp)
-  , mFocusSequenceNumber(0)
-  , modifiers(aModifiers)
-{
-}
+    : mInputType(aInputType),
+      mTime(aTime),
+      mTimeStamp(aTimeStamp),
+      mFocusSequenceNumber(0),
+      modifiers(aModifiers) {}
 
-SingleTouchData::SingleTouchData(int32_t aIdentifier, ScreenIntPoint aScreenPoint,
+SingleTouchData::SingleTouchData(int32_t aIdentifier,
+                                 ScreenIntPoint aScreenPoint,
                                  ScreenSize aRadius, float aRotationAngle,
                                  float aForce)
-  : mIdentifier(aIdentifier)
-  , mScreenPoint(aScreenPoint)
-  , mRadius(aRadius)
-  , mRotationAngle(aRotationAngle)
-  , mForce(aForce)
-{
-}
+    : mIdentifier(aIdentifier),
+      mScreenPoint(aScreenPoint),
+      mRadius(aRadius),
+      mRotationAngle(aRotationAngle),
+      mForce(aForce) {}
 
 SingleTouchData::SingleTouchData(int32_t aIdentifier,
                                  ParentLayerPoint aLocalScreenPoint,
                                  ScreenSize aRadius, float aRotationAngle,
                                  float aForce)
-  : mIdentifier(aIdentifier)
-  , mLocalScreenPoint(aLocalScreenPoint)
-  , mRadius(aRadius)
-  , mRotationAngle(aRotationAngle)
-  , mForce(aForce)
-{
-}
+    : mIdentifier(aIdentifier),
+      mLocalScreenPoint(aLocalScreenPoint),
+      mRadius(aRadius),
+      mRotationAngle(aRotationAngle),
+      mForce(aForce) {}
 
-SingleTouchData::SingleTouchData()
-{
-}
+SingleTouchData::SingleTouchData() {}
 
-already_AddRefed<Touch> SingleTouchData::ToNewDOMTouch() const
-{
+already_AddRefed<Touch> SingleTouchData::ToNewDOMTouch() const {
   MOZ_ASSERT(NS_IsMainThread(),
              "Can only create dom::Touch instances on main thread");
-  RefPtr<Touch> touch = new Touch(mIdentifier,
-                                  LayoutDeviceIntPoint::Truncate(mScreenPoint.x, mScreenPoint.y),
-                                  LayoutDeviceIntPoint::Truncate(mRadius.width, mRadius.height),
-                                  mRotationAngle,
-                                  mForce);
+  RefPtr<Touch> touch =
+      new Touch(mIdentifier,
+                LayoutDeviceIntPoint::Truncate(mScreenPoint.x, mScreenPoint.y),
+                LayoutDeviceIntPoint::Truncate(mRadius.width, mRadius.height),
+                mRotationAngle, mForce);
   return touch.forget();
 }
 
 MultiTouchInput::MultiTouchInput(MultiTouchType aType, uint32_t aTime,
                                  TimeStamp aTimeStamp, Modifiers aModifiers)
-  : InputData(MULTITOUCH_INPUT, aTime, aTimeStamp, aModifiers)
-  , mType(aType)
-  , mHandledByAPZ(false)
-{
-}
+    : InputData(MULTITOUCH_INPUT, aTime, aTimeStamp, aModifiers),
+      mType(aType),
+      mHandledByAPZ(false) {}
 
 MultiTouchInput::MultiTouchInput()
-  : InputData(MULTITOUCH_INPUT)
-  , mHandledByAPZ(false)
-{
-}
+    : InputData(MULTITOUCH_INPUT), mHandledByAPZ(false) {}
 
 MultiTouchInput::MultiTouchInput(const MultiTouchInput& aOther)
-  : InputData(MULTITOUCH_INPUT, aOther.mTime, aOther.mTimeStamp, aOther.modifiers)
-  , mType(aOther.mType)
-  , mHandledByAPZ(aOther.mHandledByAPZ)
-{
+    : InputData(MULTITOUCH_INPUT, aOther.mTime, aOther.mTimeStamp,
+                aOther.modifiers),
+      mType(aOther.mType),
+      mHandledByAPZ(aOther.mHandledByAPZ) {
   mTouches.AppendElements(aOther.mTouches);
 }
 
 MultiTouchInput::MultiTouchInput(const WidgetTouchEvent& aTouchEvent)
-  : InputData(MULTITOUCH_INPUT, aTouchEvent.mTime, aTouchEvent.mTimeStamp,
-              aTouchEvent.mModifiers)
-  , mHandledByAPZ(aTouchEvent.mFlags.mHandledByAPZ)
-{
+    : InputData(MULTITOUCH_INPUT, aTouchEvent.mTime, aTouchEvent.mTimeStamp,
+                aTouchEvent.mModifiers),
+      mHandledByAPZ(aTouchEvent.mFlags.mHandledByAPZ) {
   MOZ_ASSERT(NS_IsMainThread(),
              "Can only copy from WidgetTouchEvent on main thread");
 
@@ -137,57 +116,54 @@ MultiTouchInput::MultiTouchInput(const WidgetTouchEvent& aTouchEvent)
     float rotationAngle = domTouch->RotationAngle(CallerType::System);
     float force = domTouch->Force(CallerType::System);
 
-    SingleTouchData data(identifier,
-                         ViewAs<ScreenPixel>(domTouch->mRefPoint,
-                                             PixelCastJustification::LayoutDeviceIsScreenForUntransformedEvent),
-                         ScreenSize(radiusX, radiusY),
-                         rotationAngle,
-                         force);
+    SingleTouchData data(
+        identifier,
+        ViewAs<ScreenPixel>(
+            domTouch->mRefPoint,
+            PixelCastJustification::LayoutDeviceIsScreenForUntransformedEvent),
+        ScreenSize(radiusX, radiusY), rotationAngle, force);
 
     mTouches.AppendElement(data);
   }
 }
 
 MultiTouchInput::MultiTouchInput(const WidgetMouseEvent& aMouseEvent)
-  : InputData(MULTITOUCH_INPUT, aMouseEvent.mTime, aMouseEvent.mTimeStamp,
-              aMouseEvent.mModifiers)
-  , mHandledByAPZ(aMouseEvent.mFlags.mHandledByAPZ)
-{
+    : InputData(MULTITOUCH_INPUT, aMouseEvent.mTime, aMouseEvent.mTimeStamp,
+                aMouseEvent.mModifiers),
+      mHandledByAPZ(aMouseEvent.mFlags.mHandledByAPZ) {
   MOZ_ASSERT(NS_IsMainThread(),
              "Can only copy from WidgetMouseEvent on main thread");
   switch (aMouseEvent.mMessage) {
-  case eMouseDown:
-    mType = MULTITOUCH_START;
-    break;
-  case eMouseMove:
-    mType = MULTITOUCH_MOVE;
-    break;
-  case eMouseUp:
-    mType = MULTITOUCH_END;
-    break;
-  // The mouse pointer has been interrupted in an implementation-specific
-  // manner, such as a synchronous event or action cancelling the touch, or a
-  // touch point leaving the document window and going into a non-document
-  // area capable of handling user interactions.
-  case eMouseExitFromWidget:
-    mType = MULTITOUCH_CANCEL;
-    break;
-  default:
-    NS_WARNING("Did not assign a type to a MultiTouchInput");
-    break;
+    case eMouseDown:
+      mType = MULTITOUCH_START;
+      break;
+    case eMouseMove:
+      mType = MULTITOUCH_MOVE;
+      break;
+    case eMouseUp:
+      mType = MULTITOUCH_END;
+      break;
+    // The mouse pointer has been interrupted in an implementation-specific
+    // manner, such as a synchronous event or action cancelling the touch, or a
+    // touch point leaving the document window and going into a non-document
+    // area capable of handling user interactions.
+    case eMouseExitFromWidget:
+      mType = MULTITOUCH_CANCEL;
+      break;
+    default:
+      NS_WARNING("Did not assign a type to a MultiTouchInput");
+      break;
   }
 
-  mTouches.AppendElement(SingleTouchData(0,
-                                         ViewAs<ScreenPixel>(aMouseEvent.mRefPoint,
-                                                             PixelCastJustification::LayoutDeviceIsScreenForUntransformedEvent),
-                                         ScreenSize(1, 1),
-                                         180.0f,
-                                         1.0f));
+  mTouches.AppendElement(SingleTouchData(
+      0,
+      ViewAs<ScreenPixel>(
+          aMouseEvent.mRefPoint,
+          PixelCastJustification::LayoutDeviceIsScreenForUntransformedEvent),
+      ScreenSize(1, 1), 180.0f, 1.0f));
 }
 
-void
-MultiTouchInput::Translate(const ScreenPoint& aTranslation)
-{
+void MultiTouchInput::Translate(const ScreenPoint& aTranslation) {
   const int32_t xTranslation = (int32_t)(aTranslation.x + 0.5f);
   const int32_t yTranslation = (int32_t)(aTranslation.y + 0.5f);
 
@@ -196,29 +172,28 @@ MultiTouchInput::Translate(const ScreenPoint& aTranslation)
   }
 }
 
-WidgetTouchEvent
-MultiTouchInput::ToWidgetTouchEvent(nsIWidget* aWidget) const
-{
+WidgetTouchEvent MultiTouchInput::ToWidgetTouchEvent(nsIWidget* aWidget) const {
   MOZ_ASSERT(NS_IsMainThread(),
              "Can only convert To WidgetTouchEvent on main thread");
 
   EventMessage touchEventMessage = eVoidEvent;
   switch (mType) {
-  case MULTITOUCH_START:
-    touchEventMessage = eTouchStart;
-    break;
-  case MULTITOUCH_MOVE:
-    touchEventMessage = eTouchMove;
-    break;
-  case MULTITOUCH_END:
-    touchEventMessage = eTouchEnd;
-    break;
-  case MULTITOUCH_CANCEL:
-    touchEventMessage = eTouchCancel;
-    break;
-  default:
-    MOZ_ASSERT_UNREACHABLE("Did not assign a type to WidgetTouchEvent in MultiTouchInput");
-    break;
+    case MULTITOUCH_START:
+      touchEventMessage = eTouchStart;
+      break;
+    case MULTITOUCH_MOVE:
+      touchEventMessage = eTouchMove;
+      break;
+    case MULTITOUCH_END:
+      touchEventMessage = eTouchEnd;
+      break;
+    case MULTITOUCH_CANCEL:
+      touchEventMessage = eTouchCancel;
+      break;
+    default:
+      MOZ_ASSERT_UNREACHABLE(
+          "Did not assign a type to WidgetTouchEvent in MultiTouchInput");
+      break;
   }
 
   WidgetTouchEvent event(true, touchEventMessage, aWidget);
@@ -239,9 +214,7 @@ MultiTouchInput::ToWidgetTouchEvent(nsIWidget* aWidget) const
   return event;
 }
 
-WidgetMouseEvent
-MultiTouchInput::ToWidgetMouseEvent(nsIWidget* aWidget) const
-{
+WidgetMouseEvent MultiTouchInput::ToWidgetMouseEvent(nsIWidget* aWidget) const {
   MOZ_ASSERT(NS_IsMainThread(),
              "Can only convert To WidgetMouseEvent on main thread");
 
@@ -283,9 +256,7 @@ MultiTouchInput::ToWidgetMouseEvent(nsIWidget* aWidget) const
   return event;
 }
 
-int32_t
-MultiTouchInput::IndexOfTouch(int32_t aTouchIdentifier)
-{
+int32_t MultiTouchInput::IndexOfTouch(int32_t aTouchIdentifier) {
   for (size_t i = 0; i < mTouches.Length(); i++) {
     if (mTouches[i].mIdentifier == aTouchIdentifier) {
       return (int32_t)i;
@@ -294,12 +265,12 @@ MultiTouchInput::IndexOfTouch(int32_t aTouchIdentifier)
   return -1;
 }
 
-bool
-MultiTouchInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransform)
-{
+bool MultiTouchInput::TransformToLocal(
+    const ScreenToParentLayerMatrix4x4& aTransform) {
   for (size_t i = 0; i < mTouches.Length(); i++) {
-    Maybe<ParentLayerIntPoint> point = UntransformBy(aTransform, mTouches[i].mScreenPoint);
-    if (!point) { 
+    Maybe<ParentLayerIntPoint> point =
+        UntransformBy(aTransform, mTouches[i].mScreenPoint);
+    if (!point) {
       return false;
     }
     mTouches[i].mLocalScreenPoint = *point;
@@ -308,38 +279,33 @@ MultiTouchInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransform
 }
 
 MouseInput::MouseInput()
-  : InputData(MOUSE_INPUT)
-  , mType(MOUSE_NONE)
-  , mButtonType(NONE)
-  , mInputSource(0)
-  , mButtons(0)
-  , mHandledByAPZ(false)
-{
-}
+    : InputData(MOUSE_INPUT),
+      mType(MOUSE_NONE),
+      mButtonType(NONE),
+      mInputSource(0),
+      mButtons(0),
+      mHandledByAPZ(false) {}
 
 MouseInput::MouseInput(MouseType aType, ButtonType aButtonType,
                        uint16_t aInputSource, int16_t aButtons,
                        const ScreenPoint& aPoint, uint32_t aTime,
                        TimeStamp aTimeStamp, Modifiers aModifiers)
-  : InputData(MOUSE_INPUT, aTime, aTimeStamp, aModifiers)
-  , mType(aType)
-  , mButtonType(aButtonType)
-  , mInputSource(aInputSource)
-  , mButtons(aButtons)
-  , mOrigin(aPoint)
-  , mHandledByAPZ(false)
-{
-}
+    : InputData(MOUSE_INPUT, aTime, aTimeStamp, aModifiers),
+      mType(aType),
+      mButtonType(aButtonType),
+      mInputSource(aInputSource),
+      mButtons(aButtons),
+      mOrigin(aPoint),
+      mHandledByAPZ(false) {}
 
 MouseInput::MouseInput(const WidgetMouseEventBase& aMouseEvent)
-  : InputData(MOUSE_INPUT, aMouseEvent.mTime, aMouseEvent.mTimeStamp,
-              aMouseEvent.mModifiers)
-  , mType(MOUSE_NONE)
-  , mButtonType(NONE)
-  , mInputSource(aMouseEvent.inputSource)
-  , mButtons(aMouseEvent.buttons)
-  , mHandledByAPZ(aMouseEvent.mFlags.mHandledByAPZ)
-{
+    : InputData(MOUSE_INPUT, aMouseEvent.mTime, aMouseEvent.mTimeStamp,
+                aMouseEvent.mModifiers),
+      mType(MOUSE_NONE),
+      mButtonType(NONE),
+      mInputSource(aMouseEvent.inputSource),
+      mButtons(aMouseEvent.buttons),
+      mHandledByAPZ(aMouseEvent.mFlags.mHandledByAPZ) {
   MOZ_ASSERT(NS_IsMainThread(),
              "Can only copy from WidgetTouchEvent on main thread");
 
@@ -387,20 +353,15 @@ MouseInput::MouseInput(const WidgetMouseEventBase& aMouseEvent)
       break;
   }
 
-  mOrigin =
-    ScreenPoint(ViewAs<ScreenPixel>(aMouseEvent.mRefPoint,
+  mOrigin = ScreenPoint(ViewAs<ScreenPixel>(
+      aMouseEvent.mRefPoint,
       PixelCastJustification::LayoutDeviceIsScreenForUntransformedEvent));
 }
 
-bool
-MouseInput::IsLeftButton() const
-{
-  return mButtonType == LEFT_BUTTON;
-}
+bool MouseInput::IsLeftButton() const { return mButtonType == LEFT_BUTTON; }
 
-bool
-MouseInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransform)
-{
+bool MouseInput::TransformToLocal(
+    const ScreenToParentLayerMatrix4x4& aTransform) {
   Maybe<ParentLayerPoint> point = UntransformBy(aTransform, mOrigin);
   if (!point) {
     return false;
@@ -410,9 +371,7 @@ MouseInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransform)
   return true;
 }
 
-WidgetMouseEvent
-MouseInput::ToWidgetMouseEvent(nsIWidget* aWidget) const
-{
+WidgetMouseEvent MouseInput::ToWidgetMouseEvent(nsIWidget* aWidget) const {
   MOZ_ASSERT(NS_IsMainThread(),
              "Can only convert To WidgetTouchEvent on main thread");
 
@@ -446,11 +405,13 @@ MouseInput::ToWidgetMouseEvent(nsIWidget* aWidget) const
       msg = eMouseHitTest;
       break;
     default:
-      MOZ_ASSERT_UNREACHABLE("Did not assign a type to WidgetMouseEvent in MouseInput");
+      MOZ_ASSERT_UNREACHABLE(
+          "Did not assign a type to WidgetMouseEvent in MouseInput");
       break;
   }
 
-  WidgetMouseEvent event(true, msg, aWidget, WidgetMouseEvent::eReal, WidgetMouseEvent::eNormal);
+  WidgetMouseEvent event(true, msg, aWidget, WidgetMouseEvent::eReal,
+                         WidgetMouseEvent::eNormal);
 
   if (msg == eVoidEvent) {
     return event;
@@ -476,8 +437,8 @@ MouseInput::ToWidgetMouseEvent(nsIWidget* aWidget) const
   event.mTime = mTime;
   event.mTimeStamp = mTimeStamp;
   event.mFlags.mHandledByAPZ = mHandledByAPZ;
-  event.mRefPoint =
-    RoundedToInt(ViewAs<LayoutDevicePixel>(mOrigin,
+  event.mRefPoint = RoundedToInt(ViewAs<LayoutDevicePixel>(
+      mOrigin,
       PixelCastJustification::LayoutDeviceIsScreenForUntransformedEvent));
   event.mClickCount = clickCount;
   event.inputSource = mInputSource;
@@ -488,41 +449,35 @@ MouseInput::ToWidgetMouseEvent(nsIWidget* aWidget) const
 }
 
 PanGestureInput::PanGestureInput()
-  : InputData(PANGESTURE_INPUT)
-  , mLineOrPageDeltaX(0)
-  , mLineOrPageDeltaY(0)
-  , mUserDeltaMultiplierX(1.0)
-  , mUserDeltaMultiplierY(1.0)
-  , mHandledByAPZ(false)
-  , mFollowedByMomentum(false)
-  , mRequiresContentResponseIfCannotScrollHorizontallyInStartDirection(false)
-  , mOverscrollBehaviorAllowsSwipe(false)
-{
-}
+    : InputData(PANGESTURE_INPUT),
+      mLineOrPageDeltaX(0),
+      mLineOrPageDeltaY(0),
+      mUserDeltaMultiplierX(1.0),
+      mUserDeltaMultiplierY(1.0),
+      mHandledByAPZ(false),
+      mFollowedByMomentum(false),
+      mRequiresContentResponseIfCannotScrollHorizontallyInStartDirection(false),
+      mOverscrollBehaviorAllowsSwipe(false) {}
 
 PanGestureInput::PanGestureInput(PanGestureType aType, uint32_t aTime,
                                  TimeStamp aTimeStamp,
                                  const ScreenPoint& aPanStartPoint,
                                  const ScreenPoint& aPanDisplacement,
                                  Modifiers aModifiers)
-  : InputData(PANGESTURE_INPUT, aTime, aTimeStamp, aModifiers)
-  , mType(aType)
-  , mPanStartPoint(aPanStartPoint)
-  , mPanDisplacement(aPanDisplacement)
-  , mLineOrPageDeltaX(0)
-  , mLineOrPageDeltaY(0)
-  , mUserDeltaMultiplierX(1.0)
-  , mUserDeltaMultiplierY(1.0)
-  , mHandledByAPZ(false)
-  , mFollowedByMomentum(false)
-  , mRequiresContentResponseIfCannotScrollHorizontallyInStartDirection(false)
-  , mOverscrollBehaviorAllowsSwipe(false)
-{
-}
+    : InputData(PANGESTURE_INPUT, aTime, aTimeStamp, aModifiers),
+      mType(aType),
+      mPanStartPoint(aPanStartPoint),
+      mPanDisplacement(aPanDisplacement),
+      mLineOrPageDeltaX(0),
+      mLineOrPageDeltaY(0),
+      mUserDeltaMultiplierX(1.0),
+      mUserDeltaMultiplierY(1.0),
+      mHandledByAPZ(false),
+      mFollowedByMomentum(false),
+      mRequiresContentResponseIfCannotScrollHorizontallyInStartDirection(false),
+      mOverscrollBehaviorAllowsSwipe(false) {}
 
-bool
-PanGestureInput::IsMomentum() const
-{
+bool PanGestureInput::IsMomentum() const {
   switch (mType) {
     case PanGestureInput::PANGESTURE_MOMENTUMSTART:
     case PanGestureInput::PANGESTURE_MOMENTUMPAN:
@@ -533,19 +488,17 @@ PanGestureInput::IsMomentum() const
   }
 }
 
-WidgetWheelEvent
-PanGestureInput::ToWidgetWheelEvent(nsIWidget* aWidget) const
-{
+WidgetWheelEvent PanGestureInput::ToWidgetWheelEvent(nsIWidget* aWidget) const {
   WidgetWheelEvent wheelEvent(true, eWheel, aWidget);
   wheelEvent.mModifiers = this->modifiers;
   wheelEvent.mTime = mTime;
   wheelEvent.mTimeStamp = mTimeStamp;
-  wheelEvent.mRefPoint =
-    RoundedToInt(ViewAs<LayoutDevicePixel>(mPanStartPoint,
+  wheelEvent.mRefPoint = RoundedToInt(ViewAs<LayoutDevicePixel>(
+      mPanStartPoint,
       PixelCastJustification::LayoutDeviceIsScreenForUntransformedEvent));
   wheelEvent.buttons = 0;
   wheelEvent.mDeltaMode = nsIDOMWheelEvent::DOM_DELTA_PIXEL;
-  wheelEvent.mMayHaveMomentum = true; // pan inputs may have momentum
+  wheelEvent.mMayHaveMomentum = true;  // pan inputs may have momentum
   wheelEvent.mIsMomentum = IsMomentum();
   wheelEvent.mLineOrPageDeltaX = mLineOrPageDeltaX;
   wheelEvent.mLineOrPageDeltaY = mLineOrPageDeltaY;
@@ -556,16 +509,17 @@ PanGestureInput::ToWidgetWheelEvent(nsIWidget* aWidget) const
   return wheelEvent;
 }
 
-bool
-PanGestureInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransform)
-{ 
-  Maybe<ParentLayerPoint> panStartPoint = UntransformBy(aTransform, mPanStartPoint);
+bool PanGestureInput::TransformToLocal(
+    const ScreenToParentLayerMatrix4x4& aTransform) {
+  Maybe<ParentLayerPoint> panStartPoint =
+      UntransformBy(aTransform, mPanStartPoint);
   if (!panStartPoint) {
     return false;
   }
   mLocalPanStartPoint = *panStartPoint;
-  
-  Maybe<ParentLayerPoint> panDisplacement = UntransformVector(aTransform, mPanDisplacement, mPanStartPoint);
+
+  Maybe<ParentLayerPoint> panDisplacement =
+      UntransformVector(aTransform, mPanDisplacement, mPanStartPoint);
   if (!panDisplacement) {
     return false;
   }
@@ -573,24 +527,17 @@ PanGestureInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransform
   return true;
 }
 
-ScreenPoint
-PanGestureInput::UserMultipliedPanDisplacement() const
-{
+ScreenPoint PanGestureInput::UserMultipliedPanDisplacement() const {
   return ScreenPoint(mPanDisplacement.x * mUserDeltaMultiplierX,
                      mPanDisplacement.y * mUserDeltaMultiplierY);
 }
 
-ParentLayerPoint
-PanGestureInput::UserMultipliedLocalPanDisplacement() const
-{
+ParentLayerPoint PanGestureInput::UserMultipliedLocalPanDisplacement() const {
   return ParentLayerPoint(mLocalPanDisplacement.x * mUserDeltaMultiplierX,
                           mLocalPanDisplacement.y * mUserDeltaMultiplierY);
 }
 
-PinchGestureInput::PinchGestureInput()
-  : InputData(PINCHGESTURE_INPUT)
-{
-}
+PinchGestureInput::PinchGestureInput() : InputData(PINCHGESTURE_INPUT) {}
 
 PinchGestureInput::PinchGestureInput(PinchGestureType aType, uint32_t aTime,
                                      TimeStamp aTimeStamp,
@@ -598,17 +545,14 @@ PinchGestureInput::PinchGestureInput(PinchGestureType aType, uint32_t aTime,
                                      ParentLayerCoord aCurrentSpan,
                                      ParentLayerCoord aPreviousSpan,
                                      Modifiers aModifiers)
-  : InputData(PINCHGESTURE_INPUT, aTime, aTimeStamp, aModifiers)
-  , mType(aType)
-  , mLocalFocusPoint(aLocalFocusPoint)
-  , mCurrentSpan(aCurrentSpan)
-  , mPreviousSpan(aPreviousSpan)
-{
-}
+    : InputData(PINCHGESTURE_INPUT, aTime, aTimeStamp, aModifiers),
+      mType(aType),
+      mLocalFocusPoint(aLocalFocusPoint),
+      mCurrentSpan(aCurrentSpan),
+      mPreviousSpan(aPreviousSpan) {}
 
-bool
-PinchGestureInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransform)
-{ 
+bool PinchGestureInput::TransformToLocal(
+    const ScreenToParentLayerMatrix4x4& aTransform) {
   Maybe<ParentLayerPoint> point = UntransformBy(aTransform, mFocusPoint);
   if (!point) {
     return false;
@@ -617,34 +561,26 @@ PinchGestureInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransfo
   return true;
 }
 
-TapGestureInput::TapGestureInput()
-  : InputData(TAPGESTURE_INPUT)
-{
-}
+TapGestureInput::TapGestureInput() : InputData(TAPGESTURE_INPUT) {}
 
 TapGestureInput::TapGestureInput(TapGestureType aType, uint32_t aTime,
                                  TimeStamp aTimeStamp,
                                  const ScreenIntPoint& aPoint,
                                  Modifiers aModifiers)
-  : InputData(TAPGESTURE_INPUT, aTime, aTimeStamp, aModifiers)
-  , mType(aType)
-  , mPoint(aPoint)
-{
-}
+    : InputData(TAPGESTURE_INPUT, aTime, aTimeStamp, aModifiers),
+      mType(aType),
+      mPoint(aPoint) {}
 
 TapGestureInput::TapGestureInput(TapGestureType aType, uint32_t aTime,
                                  TimeStamp aTimeStamp,
                                  const ParentLayerPoint& aLocalPoint,
                                  Modifiers aModifiers)
-  : InputData(TAPGESTURE_INPUT, aTime, aTimeStamp, aModifiers)
-  , mType(aType)
-  , mLocalPoint(aLocalPoint)
-{
-}
+    : InputData(TAPGESTURE_INPUT, aTime, aTimeStamp, aModifiers),
+      mType(aType),
+      mLocalPoint(aLocalPoint) {}
 
-bool
-TapGestureInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransform)
-{
+bool TapGestureInput::TransformToLocal(
+    const ScreenToParentLayerMatrix4x4& aTransform) {
   Maybe<ParentLayerIntPoint> point = UntransformBy(aTransform, mPoint);
   if (!point) {
     return false;
@@ -654,17 +590,15 @@ TapGestureInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransform
 }
 
 ScrollWheelInput::ScrollWheelInput()
-  : InputData(SCROLLWHEEL_INPUT)
-  , mHandledByAPZ(false)
-  , mLineOrPageDeltaX(0)
-  , mLineOrPageDeltaY(0)
-  , mScrollSeriesNumber(0)
-  , mUserDeltaMultiplierX(1.0)
-  , mUserDeltaMultiplierY(1.0)
-  , mMayHaveMomentum(false)
-  , mIsMomentum(false)
-{
-}
+    : InputData(SCROLLWHEEL_INPUT),
+      mHandledByAPZ(false),
+      mLineOrPageDeltaX(0),
+      mLineOrPageDeltaY(0),
+      mScrollSeriesNumber(0),
+      mUserDeltaMultiplierX(1.0),
+      mUserDeltaMultiplierY(1.0),
+      mMayHaveMomentum(false),
+      mIsMomentum(false) {}
 
 ScrollWheelInput::ScrollWheelInput(uint32_t aTime, TimeStamp aTimeStamp,
                                    Modifiers aModifiers, ScrollMode aScrollMode,
@@ -672,102 +606,94 @@ ScrollWheelInput::ScrollWheelInput(uint32_t aTime, TimeStamp aTimeStamp,
                                    const ScreenPoint& aOrigin, double aDeltaX,
                                    double aDeltaY,
                                    bool aAllowToOverrideSystemScrollSpeed)
-  : InputData(SCROLLWHEEL_INPUT, aTime, aTimeStamp, aModifiers)
-  , mDeltaType(aDeltaType)
-  , mScrollMode(aScrollMode)
-  , mOrigin(aOrigin)
-  , mHandledByAPZ(false)
-  , mDeltaX(aDeltaX)
-  , mDeltaY(aDeltaY)
-  , mLineOrPageDeltaX(0)
-  , mLineOrPageDeltaY(0)
-  , mScrollSeriesNumber(0)
-  , mUserDeltaMultiplierX(1.0)
-  , mUserDeltaMultiplierY(1.0)
-  , mMayHaveMomentum(false)
-  , mIsMomentum(false)
-  , mAllowToOverrideSystemScrollSpeed(aAllowToOverrideSystemScrollSpeed)
-{
-}
+    : InputData(SCROLLWHEEL_INPUT, aTime, aTimeStamp, aModifiers),
+      mDeltaType(aDeltaType),
+      mScrollMode(aScrollMode),
+      mOrigin(aOrigin),
+      mHandledByAPZ(false),
+      mDeltaX(aDeltaX),
+      mDeltaY(aDeltaY),
+      mLineOrPageDeltaX(0),
+      mLineOrPageDeltaY(0),
+      mScrollSeriesNumber(0),
+      mUserDeltaMultiplierX(1.0),
+      mUserDeltaMultiplierY(1.0),
+      mMayHaveMomentum(false),
+      mIsMomentum(false),
+      mAllowToOverrideSystemScrollSpeed(aAllowToOverrideSystemScrollSpeed) {}
 
 ScrollWheelInput::ScrollWheelInput(const WidgetWheelEvent& aWheelEvent)
-  : InputData(SCROLLWHEEL_INPUT, aWheelEvent.mTime, aWheelEvent.mTimeStamp,
-              aWheelEvent.mModifiers)
-  , mDeltaType(DeltaTypeForDeltaMode(aWheelEvent.mDeltaMode))
-  , mScrollMode(SCROLLMODE_INSTANT)
-  , mHandledByAPZ(aWheelEvent.mFlags.mHandledByAPZ)
-  , mDeltaX(aWheelEvent.mDeltaX)
-  , mDeltaY(aWheelEvent.mDeltaY)
-  , mLineOrPageDeltaX(aWheelEvent.mLineOrPageDeltaX)
-  , mLineOrPageDeltaY(aWheelEvent.mLineOrPageDeltaY)
-  , mScrollSeriesNumber(0)
-  , mUserDeltaMultiplierX(1.0)
-  , mUserDeltaMultiplierY(1.0)
-  , mMayHaveMomentum(aWheelEvent.mMayHaveMomentum)
-  , mIsMomentum(aWheelEvent.mIsMomentum)
-  , mAllowToOverrideSystemScrollSpeed(
-      aWheelEvent.mAllowToOverrideSystemScrollSpeed)
-{
-  mOrigin =
-    ScreenPoint(ViewAs<ScreenPixel>(aWheelEvent.mRefPoint,
+    : InputData(SCROLLWHEEL_INPUT, aWheelEvent.mTime, aWheelEvent.mTimeStamp,
+                aWheelEvent.mModifiers),
+      mDeltaType(DeltaTypeForDeltaMode(aWheelEvent.mDeltaMode)),
+      mScrollMode(SCROLLMODE_INSTANT),
+      mHandledByAPZ(aWheelEvent.mFlags.mHandledByAPZ),
+      mDeltaX(aWheelEvent.mDeltaX),
+      mDeltaY(aWheelEvent.mDeltaY),
+      mLineOrPageDeltaX(aWheelEvent.mLineOrPageDeltaX),
+      mLineOrPageDeltaY(aWheelEvent.mLineOrPageDeltaY),
+      mScrollSeriesNumber(0),
+      mUserDeltaMultiplierX(1.0),
+      mUserDeltaMultiplierY(1.0),
+      mMayHaveMomentum(aWheelEvent.mMayHaveMomentum),
+      mIsMomentum(aWheelEvent.mIsMomentum),
+      mAllowToOverrideSystemScrollSpeed(
+          aWheelEvent.mAllowToOverrideSystemScrollSpeed) {
+  mOrigin = ScreenPoint(ViewAs<ScreenPixel>(
+      aWheelEvent.mRefPoint,
       PixelCastJustification::LayoutDeviceIsScreenForUntransformedEvent));
 }
 
-ScrollWheelInput::ScrollDeltaType
-ScrollWheelInput::DeltaTypeForDeltaMode(uint32_t aDeltaMode)
-{
+ScrollWheelInput::ScrollDeltaType ScrollWheelInput::DeltaTypeForDeltaMode(
+    uint32_t aDeltaMode) {
   switch (aDeltaMode) {
-  case nsIDOMWheelEvent::DOM_DELTA_LINE:
-    return SCROLLDELTA_LINE;
-  case nsIDOMWheelEvent::DOM_DELTA_PAGE:
-    return SCROLLDELTA_PAGE;
-  case nsIDOMWheelEvent::DOM_DELTA_PIXEL:
-    return SCROLLDELTA_PIXEL;
-  default:
-    MOZ_CRASH();
+    case nsIDOMWheelEvent::DOM_DELTA_LINE:
+      return SCROLLDELTA_LINE;
+    case nsIDOMWheelEvent::DOM_DELTA_PAGE:
+      return SCROLLDELTA_PAGE;
+    case nsIDOMWheelEvent::DOM_DELTA_PIXEL:
+      return SCROLLDELTA_PIXEL;
+    default:
+      MOZ_CRASH();
   }
   return SCROLLDELTA_LINE;
 }
 
-uint32_t
-ScrollWheelInput::DeltaModeForDeltaType(ScrollDeltaType aDeltaType)
-{
+uint32_t ScrollWheelInput::DeltaModeForDeltaType(ScrollDeltaType aDeltaType) {
   switch (aDeltaType) {
-  case ScrollWheelInput::SCROLLDELTA_LINE:
-    return nsIDOMWheelEvent::DOM_DELTA_LINE;
-  case ScrollWheelInput::SCROLLDELTA_PAGE:
-    return nsIDOMWheelEvent::DOM_DELTA_PAGE;
-  case ScrollWheelInput::SCROLLDELTA_PIXEL:
-  default:
-    return nsIDOMWheelEvent::DOM_DELTA_PIXEL;
+    case ScrollWheelInput::SCROLLDELTA_LINE:
+      return nsIDOMWheelEvent::DOM_DELTA_LINE;
+    case ScrollWheelInput::SCROLLDELTA_PAGE:
+      return nsIDOMWheelEvent::DOM_DELTA_PAGE;
+    case ScrollWheelInput::SCROLLDELTA_PIXEL:
+    default:
+      return nsIDOMWheelEvent::DOM_DELTA_PIXEL;
   }
 }
 
-nsIScrollableFrame::ScrollUnit
-ScrollWheelInput::ScrollUnitForDeltaType(ScrollDeltaType aDeltaType)
-{
+nsIScrollableFrame::ScrollUnit ScrollWheelInput::ScrollUnitForDeltaType(
+    ScrollDeltaType aDeltaType) {
   switch (aDeltaType) {
-  case SCROLLDELTA_LINE:
-    return nsIScrollableFrame::LINES;
-  case SCROLLDELTA_PAGE:
-    return nsIScrollableFrame::PAGES;
-  case SCROLLDELTA_PIXEL:
-    return nsIScrollableFrame::DEVICE_PIXELS;
-  default:
-    MOZ_CRASH();
+    case SCROLLDELTA_LINE:
+      return nsIScrollableFrame::LINES;
+    case SCROLLDELTA_PAGE:
+      return nsIScrollableFrame::PAGES;
+    case SCROLLDELTA_PIXEL:
+      return nsIScrollableFrame::DEVICE_PIXELS;
+    default:
+      MOZ_CRASH();
   }
   return nsIScrollableFrame::LINES;
 }
 
-WidgetWheelEvent
-ScrollWheelInput::ToWidgetWheelEvent(nsIWidget* aWidget) const
-{
+WidgetWheelEvent ScrollWheelInput::ToWidgetWheelEvent(
+    nsIWidget* aWidget) const {
   WidgetWheelEvent wheelEvent(true, eWheel, aWidget);
   wheelEvent.mModifiers = this->modifiers;
   wheelEvent.mTime = mTime;
   wheelEvent.mTimeStamp = mTimeStamp;
-  wheelEvent.mRefPoint =
-    RoundedToInt(ViewAs<LayoutDevicePixel>(mOrigin,
+  wheelEvent.mRefPoint = RoundedToInt(ViewAs<LayoutDevicePixel>(
+      mOrigin,
       PixelCastJustification::LayoutDeviceIsScreenForUntransformedEvent));
   wheelEvent.buttons = 0;
   wheelEvent.mDeltaMode = DeltaModeForDeltaType(mDeltaType);
@@ -778,15 +704,14 @@ ScrollWheelInput::ToWidgetWheelEvent(nsIWidget* aWidget) const
   wheelEvent.mLineOrPageDeltaX = mLineOrPageDeltaX;
   wheelEvent.mLineOrPageDeltaY = mLineOrPageDeltaY;
   wheelEvent.mAllowToOverrideSystemScrollSpeed =
-    mAllowToOverrideSystemScrollSpeed;
+      mAllowToOverrideSystemScrollSpeed;
   wheelEvent.mFlags.mHandledByAPZ = mHandledByAPZ;
   wheelEvent.mFocusSequenceNumber = mFocusSequenceNumber;
   return wheelEvent;
 }
 
-bool
-ScrollWheelInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransform)
-{
+bool ScrollWheelInput::TransformToLocal(
+    const ScreenToParentLayerMatrix4x4& aTransform) {
   Maybe<ParentLayerPoint> point = UntransformBy(aTransform, mOrigin);
   if (!point) {
     return false;
@@ -795,22 +720,16 @@ ScrollWheelInput::TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransfor
   return true;
 }
 
-bool
-ScrollWheelInput::IsCustomizedByUserPrefs() const
-{
-  return mUserDeltaMultiplierX != 1.0 ||
-         mUserDeltaMultiplierY != 1.0;
+bool ScrollWheelInput::IsCustomizedByUserPrefs() const {
+  return mUserDeltaMultiplierX != 1.0 || mUserDeltaMultiplierY != 1.0;
 }
 
 KeyboardInput::KeyboardInput(const WidgetKeyboardEvent& aEvent)
-  : InputData(KEYBOARD_INPUT,
-              aEvent.mTime,
-              aEvent.mTimeStamp,
-              aEvent.mModifiers)
-  , mKeyCode(aEvent.mKeyCode)
-  , mCharCode(aEvent.mCharCode)
-  , mHandledByAPZ(false)
-{
+    : InputData(KEYBOARD_INPUT, aEvent.mTime, aEvent.mTimeStamp,
+                aEvent.mModifiers),
+      mKeyCode(aEvent.mKeyCode),
+      mCharCode(aEvent.mCharCode),
+      mHandledByAPZ(false) {
   switch (aEvent.mMessage) {
     case eKeyPress: {
       mType = KeyboardInput::KEY_PRESS;
@@ -833,11 +752,9 @@ KeyboardInput::KeyboardInput(const WidgetKeyboardEvent& aEvent)
 }
 
 KeyboardInput::KeyboardInput()
-  : InputData(KEYBOARD_INPUT)
-  , mKeyCode(0)
-  , mCharCode(0)
-  , mHandledByAPZ(false)
-{
-}
+    : InputData(KEYBOARD_INPUT),
+      mKeyCode(0),
+      mCharCode(0),
+      mHandledByAPZ(false) {}
 
-} // namespace mozilla
+}  // namespace mozilla
