@@ -18,7 +18,8 @@
 #include "mozilla/gfx/MatrixFwd.h"
 #include "mozilla/layers/KeyboardScrollAction.h"
 
-template<class E> struct already_AddRefed;
+template <class E>
+struct already_AddRefed;
 class nsIWidget;
 
 namespace mozilla {
@@ -26,12 +27,13 @@ namespace mozilla {
 namespace layers {
 class PAPZCTreeManagerParent;
 class APZCTreeManagerChild;
-}
+}  // namespace layers
 
 namespace dom {
 class Touch;
-} // namespace dom
+}  // namespace dom
 
+// clang-format off
 MOZ_DEFINE_ENUM(
   InputType, (
     MULTITOUCH_INPUT,
@@ -42,6 +44,7 @@ MOZ_DEFINE_ENUM(
     SCROLLWHEEL_INPUT,
     KEYBOARD_INPUT
 ));
+// clang-format on
 
 class MultiTouchInput;
 class MouseInput;
@@ -55,22 +58,19 @@ class KeyboardInput;
 // from InputType (eventually probably almost as many as *Events.h has), it
 // will be more and more clear what's going on with a macro that shortens the
 // definition of the RTTI functions.
-#define INPUTDATA_AS_CHILD_TYPE(type, enumID) \
-  const type& As##type() const \
-  { \
+#define INPUTDATA_AS_CHILD_TYPE(type, enumID)                       \
+  const type& As##type() const {                                    \
     MOZ_ASSERT(mInputType == enumID, "Invalid cast of InputData."); \
-    return (const type&) *this; \
-  } \
-  type& As##type() \
-  { \
+    return (const type&)*this;                                      \
+  }                                                                 \
+  type& As##type() {                                                \
     MOZ_ASSERT(mInputType == enumID, "Invalid cast of InputData."); \
-    return (type&) *this; \
+    return (type&)*this;                                            \
   }
 
 /** Base input data class. Should never be instantiated. */
-class InputData
-{
-public:
+class InputData {
+ public:
   // Warning, this class is serialized and sent over IPC. Any change to its
   // fields must be reflected in its ParamTraits<>, in nsGUIEventIPC.h
   InputType mInputType;
@@ -84,8 +84,8 @@ public:
   // platform-specific event times (see bug 77992).
   TimeStamp mTimeStamp;
   // The sequence number of the last potentially focus changing event handled
-  // by APZ. This is used to track when that event has been processed by content,
-  // and focus can be reconfirmed for async keyboard scrolling.
+  // by APZ. This is used to track when that event has been processed by
+  // content, and focus can be reconfirmed for async keyboard scrolling.
   uint64_t mFocusSequenceNumber;
 
   Modifiers modifiers;
@@ -101,7 +101,7 @@ public:
   virtual ~InputData();
   explicit InputData(InputType aInputType);
 
-protected:
+ protected:
   InputData(InputType aInputType, uint32_t aTime, TimeStamp aTimeStamp,
             Modifiers aModifiers);
 };
@@ -121,26 +121,20 @@ protected:
  *
  * fixme/bug 775746: Make dom::Touch inherit from this class.
  */
-class SingleTouchData
-{
-public:
+class SingleTouchData {
+ public:
   // Construct a SingleTouchData from a Screen point.
   // mLocalScreenPoint remains (0,0) unless it's set later.
-  SingleTouchData(int32_t aIdentifier,
-                  ScreenIntPoint aScreenPoint,
-                  ScreenSize aRadius,
-                  float aRotationAngle,
-                  float aForce);
+  SingleTouchData(int32_t aIdentifier, ScreenIntPoint aScreenPoint,
+                  ScreenSize aRadius, float aRotationAngle, float aForce);
 
   // Construct a SingleTouchData from a ParentLayer point.
   // mScreenPoint remains (0,0) unless it's set later.
   // Note: if APZ starts using the radius for anything, we should add a local
-  // version of that too, and have this constructor take it as a ParentLayerSize.
-  SingleTouchData(int32_t aIdentifier,
-                  ParentLayerPoint aLocalScreenPoint,
-                  ScreenSize aRadius,
-                  float aRotationAngle,
-                  float aForce);
+  // version of that too, and have this constructor take it as a
+  // ParentLayerSize.
+  SingleTouchData(int32_t aIdentifier, ParentLayerPoint aLocalScreenPoint,
+                  ScreenSize aRadius, float aRotationAngle, float aForce);
 
   SingleTouchData();
 
@@ -149,8 +143,9 @@ public:
   // Warning, this class is serialized and sent over IPC. Any change to its
   // fields must be reflected in its ParamTraits<>, in nsGUIEventIPC.h
 
-  // A unique number assigned to each SingleTouchData within a MultiTouchInput so
-  // that they can be easily distinguished when handling a touch start/move/end.
+  // A unique number assigned to each SingleTouchData within a MultiTouchInput
+  // so that they can be easily distinguished when handling a touch
+  // start/move/end.
   int32_t mIdentifier;
 
   // Point on the screen that the touch hit, in device pixels. They are
@@ -184,9 +179,9 @@ public:
  *
  * Stores an array of SingleTouchData.
  */
-class MultiTouchInput : public InputData
-{
-public:
+class MultiTouchInput : public InputData {
+ public:
+  // clang-format off
   MOZ_DEFINE_ENUM_AT_CLASS_SCOPE(
     MultiTouchType, (
       MULTITOUCH_START,
@@ -194,6 +189,7 @@ public:
       MULTITOUCH_END,
       MULTITOUCH_CANCEL
   ));
+  // clang-format on
 
   MultiTouchInput(MultiTouchType aType, uint32_t aTime, TimeStamp aTimeStamp,
                   Modifiers aModifiers);
@@ -225,16 +221,15 @@ public:
   bool mHandledByAPZ;
 };
 
-class MouseInput : public InputData
-{
-protected:
+class MouseInput : public InputData {
+ protected:
   friend mozilla::layers::PAPZCTreeManagerParent;
   friend mozilla::layers::APZCTreeManagerChild;
 
   MouseInput();
 
-public:
-
+ public:
+  // clang-format off
   MOZ_DEFINE_ENUM_AT_CLASS_SCOPE(
     MouseType, (
       MOUSE_NONE,
@@ -255,6 +250,7 @@ public:
       RIGHT_BUTTON,
       NONE
   ));
+  // clang-format on
 
   MouseInput(MouseType aType, ButtonType aButtonType, uint16_t aInputSource,
              int16_t aButtons, const ScreenPoint& aPoint, uint32_t aTime,
@@ -281,15 +277,15 @@ public:
  * Encapsulation class for pan events, can be used off-main-thread.
  * These events are currently only used for scrolling on desktop.
  */
-class PanGestureInput : public InputData
-{
-protected:
+class PanGestureInput : public InputData {
+ protected:
   friend mozilla::layers::PAPZCTreeManagerParent;
   friend mozilla::layers::APZCTreeManagerChild;
 
   PanGestureInput();
 
-public:
+ public:
+  // clang-format off
   MOZ_DEFINE_ENUM_AT_CLASS_SCOPE(
     PanGestureType, (
       // MayStart: Dispatched before any actual panning has occurred but when a
@@ -335,13 +331,11 @@ public:
       // user has stopped the animation by putting their fingers on a touchpad.
       PANGESTURE_MOMENTUMEND
   ));
+  // clang-format on
 
-  PanGestureInput(PanGestureType aType,
-                  uint32_t aTime,
-                  TimeStamp aTimeStamp,
+  PanGestureInput(PanGestureType aType, uint32_t aTime, TimeStamp aTimeStamp,
                   const ScreenPoint& aPanStartPoint,
-                  const ScreenPoint& aPanDisplacement,
-                  Modifiers aModifiers);
+                  const ScreenPoint& aPanDisplacement, Modifiers aModifiers);
 
   bool IsMomentum() const;
 
@@ -398,28 +392,30 @@ public:
 
 /**
  * Encapsulation class for pinch events. In general, these will be generated by
- * a gesture listener by looking at SingleTouchData/MultiTouchInput instances and
- * determining whether or not the user was trying to do a gesture.
+ * a gesture listener by looking at SingleTouchData/MultiTouchInput instances
+ * and determining whether or not the user was trying to do a gesture.
  */
-class PinchGestureInput : public InputData
-{
-protected:
+class PinchGestureInput : public InputData {
+ protected:
   friend mozilla::layers::PAPZCTreeManagerParent;
   friend mozilla::layers::APZCTreeManagerChild;
 
   PinchGestureInput();
 
-public:
+ public:
+  // clang-format off
   MOZ_DEFINE_ENUM_AT_CLASS_SCOPE(
     PinchGestureType, (
       PINCHGESTURE_START,
       PINCHGESTURE_SCALE,
       PINCHGESTURE_END
   ));
+  // clang-format on
 
   // Construct a pinch gesture from a ParentLayer point.
   // mFocusPoint remains (0,0) unless it's set later.
-  PinchGestureInput(PinchGestureType aType, uint32_t aTime, TimeStamp aTimeStamp,
+  PinchGestureInput(PinchGestureType aType, uint32_t aTime,
+                    TimeStamp aTimeStamp,
                     const ParentLayerPoint& aLocalFocusPoint,
                     ParentLayerCoord aCurrentSpan,
                     ParentLayerCoord aPreviousSpan, Modifiers aModifiers);
@@ -455,18 +451,18 @@ public:
 
 /**
  * Encapsulation class for tap events. In general, these will be generated by
- * a gesture listener by looking at SingleTouchData/MultiTouchInput instances and
- * determining whether or not the user was trying to do a gesture.
+ * a gesture listener by looking at SingleTouchData/MultiTouchInput instances
+ * and determining whether or not the user was trying to do a gesture.
  */
-class TapGestureInput : public InputData
-{
-protected:
+class TapGestureInput : public InputData {
+ protected:
   friend mozilla::layers::PAPZCTreeManagerParent;
   friend mozilla::layers::APZCTreeManagerChild;
 
   TapGestureInput();
 
-public:
+ public:
+  // clang-format off
   MOZ_DEFINE_ENUM_AT_CLASS_SCOPE(
     TapGestureType, (
       TAPGESTURE_LONG,
@@ -477,6 +473,7 @@ public:
       TAPGESTURE_SECOND, // See GeckoContentController::TapType::eSecondTap
       TAPGESTURE_CANCEL
   ));
+  // clang-format on
 
   // Construct a tap gesture from a Screen point.
   // mLocalPoint remains (0,0) unless it's set later.
@@ -505,19 +502,19 @@ public:
 // Encapsulation class for scroll-wheel events. These are generated by mice
 // with physical scroll wheels, and on Windows by most touchpads when using
 // scroll gestures.
-class ScrollWheelInput : public InputData
-{
-protected:
+class ScrollWheelInput : public InputData {
+ protected:
   friend mozilla::layers::PAPZCTreeManagerParent;
   friend mozilla::layers::APZCTreeManagerChild;
 
   ScrollWheelInput();
 
-public:
+ public:
+  // clang-format off
   MOZ_DEFINE_ENUM_AT_CLASS_SCOPE(
     ScrollDeltaType, (
-      // There are three kinds of scroll delta modes in Gecko: "page", "line" and
-      // "pixel".
+      // There are three kinds of scroll delta modes in Gecko: "page", "line"
+      // and "pixel".
       SCROLLDELTA_LINE,
       SCROLLDELTA_PAGE,
       SCROLLDELTA_PIXEL
@@ -529,6 +526,7 @@ public:
       SCROLLMODE_SMOOTH
     )
   );
+  // clang-format on
 
   ScrollWheelInput(uint32_t aTime, TimeStamp aTimeStamp, Modifiers aModifiers,
                    ScrollMode aScrollMode, ScrollDeltaType aDeltaType,
@@ -538,7 +536,8 @@ public:
 
   static ScrollDeltaType DeltaTypeForDeltaMode(uint32_t aDeltaMode);
   static uint32_t DeltaModeForDeltaType(ScrollDeltaType aDeltaType);
-  static nsIScrollableFrame::ScrollUnit ScrollUnitForDeltaType(ScrollDeltaType aDeltaType);
+  static nsIScrollableFrame::ScrollUnit ScrollUnitForDeltaType(
+      ScrollDeltaType aDeltaType);
 
   WidgetWheelEvent ToWidgetWheelEvent(nsIWidget* aWidget) const;
   bool TransformToLocal(const ScreenToParentLayerMatrix4x4& aTransform);
@@ -585,13 +584,11 @@ public:
   bool mAllowToOverrideSystemScrollSpeed;
 };
 
-class KeyboardInput : public InputData
-{
-public:
+class KeyboardInput : public InputData {
+ public:
   typedef mozilla::layers::KeyboardScrollAction KeyboardScrollAction;
 
-  enum KeyboardEventType
-  {
+  enum KeyboardEventType {
     KEY_DOWN,
     KEY_PRESS,
     KEY_UP,
@@ -618,13 +615,13 @@ public:
   // only used in APZ and is NOT serialized over IPC.
   KeyboardScrollAction mAction;
 
-protected:
+ protected:
   friend mozilla::layers::PAPZCTreeManagerParent;
   friend mozilla::layers::APZCTreeManagerChild;
 
   KeyboardInput();
 };
 
-} // namespace mozilla
+}  // namespace mozilla
 
-#endif // InputData_h__
+#endif  // InputData_h__
