@@ -32,15 +32,13 @@ namespace mozilla {
 
 namespace dom {
 class TabChild;
-} // namespace dom
+}  // namespace dom
 
 namespace widget {
 
 struct AutoCacheNativeKeyCommands;
 
-class PuppetWidget : public nsBaseWidget
-                   , public TextEventDispatcherListener
-{
+class PuppetWidget : public nsBaseWidget, public TextEventDispatcherListener {
   typedef mozilla::CSSRect CSSRect;
   typedef mozilla::dom::TabChild TabChild;
   typedef mozilla::gfx::DrawTarget DrawTarget;
@@ -48,66 +46,56 @@ class PuppetWidget : public nsBaseWidget
   // Avoiding to make compiler confused between mozilla::widget and nsIWidget.
   typedef mozilla::widget::TextEventDispatcher TextEventDispatcher;
   typedef mozilla::widget::TextEventDispatcherListener
-                             TextEventDispatcherListener;
+      TextEventDispatcherListener;
 
   typedef nsBaseWidget Base;
 
   // The width and height of the "widget" are clamped to this.
   static const size_t kMaxDimension;
 
-public:
+ public:
   explicit PuppetWidget(TabChild* aTabChild);
 
-protected:
+ protected:
   virtual ~PuppetWidget();
 
-public:
+ public:
   NS_DECL_ISUPPORTS_INHERITED
 
   // PuppetWidget creation is infallible, hence InfallibleCreate(), which
   // Create() calls.
-  using nsBaseWidget::Create; // for Create signature not overridden here
-  virtual nsresult Create(nsIWidget* aParent,
-                          nsNativeWidget aNativeParent,
+  using nsBaseWidget::Create;  // for Create signature not overridden here
+  virtual nsresult Create(nsIWidget* aParent, nsNativeWidget aNativeParent,
                           const LayoutDeviceIntRect& aRect,
-                          nsWidgetInitData* aInitData = nullptr)
-                          override;
-  void InfallibleCreate(nsIWidget* aParent,
-                        nsNativeWidget aNativeParent,
+                          nsWidgetInitData* aInitData = nullptr) override;
+  void InfallibleCreate(nsIWidget* aParent, nsNativeWidget aNativeParent,
                         const LayoutDeviceIntRect& aRect,
                         nsWidgetInitData* aInitData = nullptr);
 
   void InitIMEState();
 
-  virtual already_AddRefed<nsIWidget>
-  CreateChild(const LayoutDeviceIntRect& aRect,
-              nsWidgetInitData* aInitData = nullptr,
-              bool aForceUseIWidgetParent = false) override;
+  virtual already_AddRefed<nsIWidget> CreateChild(
+      const LayoutDeviceIntRect& aRect, nsWidgetInitData* aInitData = nullptr,
+      bool aForceUseIWidgetParent = false) override;
 
   virtual void Destroy() override;
 
   virtual void Show(bool aState) override;
 
-  virtual bool IsVisible() const override
-  { return mVisible; }
+  virtual bool IsVisible() const override { return mVisible; }
 
-  virtual void ConstrainPosition(bool     /*ignored aAllowSlop*/,
-                                 int32_t* aX,
-                                 int32_t* aY) override
-  { *aX = kMaxDimension; *aY = kMaxDimension; }
+  virtual void ConstrainPosition(bool /*ignored aAllowSlop*/, int32_t* aX,
+                                 int32_t* aY) override {
+    *aX = kMaxDimension;
+    *aY = kMaxDimension;
+  }
 
   // Widget position is controlled by the parent process via TabChild.
   virtual void Move(double aX, double aY) override {}
 
-  virtual void Resize(double aWidth,
-                      double aHeight,
-                      bool   aRepaint) override;
-  virtual void Resize(double aX,
-                      double aY,
-                      double aWidth,
-                      double aHeight,
-                      bool   aRepaint) override
-  {
+  virtual void Resize(double aWidth, double aHeight, bool aRepaint) override;
+  virtual void Resize(double aX, double aY, double aWidth, double aHeight,
+                      bool aRepaint) override {
     if (!mBounds.IsEqualXY(aX, aY)) {
       NotifyWindowMoved(aX, aY);
     }
@@ -117,14 +105,13 @@ public:
 
   // XXX/cjones: copying gtk behavior here; unclear what disabling a
   // widget is supposed to entail
-  virtual void Enable(bool aState) override
-  { mEnabled = aState; }
-  virtual bool IsEnabled() const override
-  { return mEnabled; }
+  virtual void Enable(bool aState) override { mEnabled = aState; }
+  virtual bool IsEnabled() const override { return mEnabled; }
 
   virtual nsresult SetFocus(bool aRaise = false) override;
 
-  virtual nsresult ConfigureChildren(const nsTArray<Configuration>& aConfigurations) override;
+  virtual nsresult ConfigureChildren(
+      const nsTArray<Configuration>& aConfigurations) override;
 
   virtual void Invalidate(const LayoutDeviceIntRect& aRect) override;
 
@@ -135,11 +122,13 @@ public:
 #endif
 
   // PuppetWidgets don't have any concept of titles.
-  virtual nsresult SetTitle(const nsAString& aTitle) override
-  { return NS_ERROR_UNEXPECTED; }
+  virtual nsresult SetTitle(const nsAString& aTitle) override {
+    return NS_ERROR_UNEXPECTED;
+  }
 
-  virtual LayoutDeviceIntPoint WidgetToScreenOffset() override
-  { return GetWindowPosition() + GetChromeOffset(); }
+  virtual LayoutDeviceIntPoint WidgetToScreenOffset() override {
+    return GetWindowPosition() + GetChromeOffset();
+  }
 
   int32_t RoundsWidgetCoordinatesTo() override;
 
@@ -149,17 +138,17 @@ public:
   virtual nsresult DispatchEvent(WidgetGUIEvent* aEvent,
                                  nsEventStatus& aStatus) override;
   nsEventStatus DispatchInputEvent(WidgetInputEvent* aEvent) override;
-  void SetConfirmedTargetAPZC(uint64_t aInputBlockId,
-                              const nsTArray<ScrollableLayerGuid>& aTargets) const override;
-  void UpdateZoomConstraints(const uint32_t& aPresShellId,
-                             const FrameMetrics::ViewID& aViewId,
-                             const mozilla::Maybe<ZoomConstraints>& aConstraints) override;
+  void SetConfirmedTargetAPZC(
+      uint64_t aInputBlockId,
+      const nsTArray<ScrollableLayerGuid>& aTargets) const override;
+  void UpdateZoomConstraints(
+      const uint32_t& aPresShellId, const FrameMetrics::ViewID& aViewId,
+      const mozilla::Maybe<ZoomConstraints>& aConstraints) override;
   bool AsyncPanZoomEnabled() const override;
 
   virtual void GetEditCommands(
-                 NativeKeyBindingsType aType,
-                 const mozilla::WidgetKeyboardEvent& aEvent,
-                 nsTArray<mozilla::CommandInt>& aCommands) override;
+      NativeKeyBindingsType aType, const mozilla::WidgetKeyboardEvent& aEvent,
+      nsTArray<mozilla::CommandInt>& aCommands) override;
 
   friend struct AutoCacheNativeKeyCommands;
 
@@ -173,41 +162,42 @@ public:
   // same-process subdocuments, we force the widget here to be
   // transparent, which in turn will cause layout to use a transparent
   // backstop background color.
-  virtual nsTransparencyMode GetTransparencyMode() override
-  { return eTransparencyTransparent; }
+  virtual nsTransparencyMode GetTransparencyMode() override {
+    return eTransparencyTransparent;
+  }
 
-  virtual LayerManager*
-  GetLayerManager(PLayerTransactionChild* aShadowManager = nullptr,
-                  LayersBackend aBackendHint = mozilla::layers::LayersBackend::LAYERS_NONE,
-                  LayerManagerPersistence aPersistence = LAYER_MANAGER_CURRENT) override;
+  virtual LayerManager* GetLayerManager(
+      PLayerTransactionChild* aShadowManager = nullptr,
+      LayersBackend aBackendHint = mozilla::layers::LayersBackend::LAYERS_NONE,
+      LayerManagerPersistence aPersistence = LAYER_MANAGER_CURRENT) override;
 
   // This is used for creating remote layer managers and for re-creating
-  // them after a compositor reset. The lambda aInitializeFunc is used to perform
-  // any caller-required initialization for the newly created layer
+  // them after a compositor reset. The lambda aInitializeFunc is used to
+  // perform any caller-required initialization for the newly created layer
   // manager; in the event of a failure, return false and it will destroy the
   // new layer manager without changing the state of the widget.
-  bool CreateRemoteLayerManager(const std::function<bool(LayerManager*)>& aInitializeFunc);
+  bool CreateRemoteLayerManager(
+      const std::function<bool(LayerManager*)>& aInitializeFunc);
 
-  bool HasLayerManager()
-  {
-    return !!mLayerManager;
-  }
+  bool HasLayerManager() { return !!mLayerManager; }
 
   virtual void SetInputContext(const InputContext& aContext,
                                const InputContextAction& aAction) override;
   virtual InputContext GetInputContext() override;
   virtual NativeIMEContext GetNativeIMEContext() override;
-  TextEventDispatcherListener* GetNativeTextEventDispatcherListener() override
-  {
-    return mNativeTextEventDispatcherListener ?
-             mNativeTextEventDispatcherListener.get() : this;
+  TextEventDispatcherListener* GetNativeTextEventDispatcherListener() override {
+    return mNativeTextEventDispatcherListener
+               ? mNativeTextEventDispatcherListener.get()
+               : this;
+  }
+  void SetNativeTextEventDispatcherListener(
+      TextEventDispatcherListener* aListener) {
+    mNativeTextEventDispatcherListener = aListener;
   }
-  void SetNativeTextEventDispatcherListener(TextEventDispatcherListener* aListener)
-  { mNativeTextEventDispatcherListener = aListener; }
 
   virtual void SetCursor(nsCursor aCursor) override;
-  virtual nsresult SetCursor(imgIContainer* aCursor,
-                             uint32_t aHotspotX, uint32_t aHotspotY) override;
+  virtual nsresult SetCursor(imgIContainer* aCursor, uint32_t aHotspotX,
+                             uint32_t aHotspotY) override;
 
   virtual void ClearCachedCursor() override;
 
@@ -225,8 +215,7 @@ public:
 
   virtual TabChild* GetOwningTabChild() override { return mTabChild; }
 
-  void UpdateBackingScaleCache(float aDpi, int32_t aRounding, double aScale)
-  {
+  void UpdateBackingScaleCache(float aDpi, int32_t aRounding, double aScale) {
     mDPI = aDpi;
     mRounding = aRounding;
     mDefaultScale = aScale;
@@ -242,35 +231,28 @@ public:
 
   virtual LayoutDeviceIntRect GetScreenBounds() override;
 
-  virtual MOZ_MUST_USE nsresult
-  StartPluginIME(const mozilla::WidgetKeyboardEvent& aKeyboardEvent,
-                 int32_t aPanelX, int32_t aPanelY,
-                 nsString& aCommitted) override;
+  virtual MOZ_MUST_USE nsresult StartPluginIME(
+      const mozilla::WidgetKeyboardEvent& aKeyboardEvent, int32_t aPanelX,
+      int32_t aPanelY, nsString& aCommitted) override;
 
   virtual void SetPluginFocused(bool& aFocused) override;
   virtual void DefaultProcOfPluginEvent(
-                 const mozilla::WidgetPluginEvent& aEvent) override;
+      const mozilla::WidgetPluginEvent& aEvent) override;
 
-  virtual nsresult SynthesizeNativeKeyEvent(int32_t aNativeKeyboardLayout,
-                                            int32_t aNativeKeyCode,
-                                            uint32_t aModifierFlags,
-                                            const nsAString& aCharacters,
-                                            const nsAString& aUnmodifiedCharacters,
-                                            nsIObserver* aObserver) override;
+  virtual nsresult SynthesizeNativeKeyEvent(
+      int32_t aNativeKeyboardLayout, int32_t aNativeKeyCode,
+      uint32_t aModifierFlags, const nsAString& aCharacters,
+      const nsAString& aUnmodifiedCharacters, nsIObserver* aObserver) override;
   virtual nsresult SynthesizeNativeMouseEvent(LayoutDeviceIntPoint aPoint,
                                               uint32_t aNativeMessage,
                                               uint32_t aModifierFlags,
                                               nsIObserver* aObserver) override;
   virtual nsresult SynthesizeNativeMouseMove(LayoutDeviceIntPoint aPoint,
                                              nsIObserver* aObserver) override;
-  virtual nsresult SynthesizeNativeMouseScrollEvent(LayoutDeviceIntPoint aPoint,
-                                                    uint32_t aNativeMessage,
-                                                    double aDeltaX,
-                                                    double aDeltaY,
-                                                    double aDeltaZ,
-                                                    uint32_t aModifierFlags,
-                                                    uint32_t aAdditionalFlags,
-                                                    nsIObserver* aObserver) override;
+  virtual nsresult SynthesizeNativeMouseScrollEvent(
+      LayoutDeviceIntPoint aPoint, uint32_t aNativeMessage, double aDeltaX,
+      double aDeltaY, double aDeltaZ, uint32_t aModifierFlags,
+      uint32_t aAdditionalFlags, nsIObserver* aObserver) override;
   virtual nsresult SynthesizeNativeTouchPoint(uint32_t aPointerId,
                                               TouchPointerState aPointerState,
                                               LayoutDeviceIntPoint aPoint,
@@ -283,10 +265,12 @@ public:
   virtual nsresult ClearNativeTouchSequence(nsIObserver* aObserver) override;
   virtual uint32_t GetMaxTouchPoints() const override;
 
-  virtual void StartAsyncScrollbarDrag(const AsyncDragMetrics& aDragMetrics) override;
+  virtual void StartAsyncScrollbarDrag(
+      const AsyncDragMetrics& aDragMetrics) override;
 
   virtual void SetCandidateWindowForPlugin(
-                 const CandidateWindowPosition& aPosition) override;
+      const CandidateWindowPosition& aPosition) override;
+  virtual void EnableIMEForPlugin(bool aEnable) override;
 
   virtual void ZoomToRect(const uint32_t& aPresShellId,
                           const FrameMetrics::ViewID& aViewId,
@@ -299,29 +283,27 @@ public:
                                      bool aIsConsumed);
 
   virtual nsresult OnWindowedPluginKeyEvent(
-                     const NativeEventData& aKeyEventData,
-                     nsIKeyEventInPluginCallback* aCallback) override;
+      const NativeEventData& aKeyEventData,
+      nsIKeyEventInPluginCallback* aCallback) override;
 
   virtual void LookUpDictionary(
-                 const nsAString& aText,
-                 const nsTArray<mozilla::FontRange>& aFontRangeArray,
-                 const bool aIsVertical,
-                 const LayoutDeviceIntPoint& aPoint) override;
+      const nsAString& aText,
+      const nsTArray<mozilla::FontRange>& aFontRangeArray,
+      const bool aIsVertical, const LayoutDeviceIntPoint& aPoint) override;
 
   // TextEventDispatcherListener
   using nsBaseWidget::NotifyIME;
   NS_IMETHOD NotifyIME(TextEventDispatcher* aTextEventDispatcher,
                        const IMENotification& aNotification) override;
   NS_IMETHOD_(IMENotificationRequests) GetIMENotificationRequests() override;
-  NS_IMETHOD_(void) OnRemovedFrom(
-                      TextEventDispatcher* aTextEventDispatcher) override;
-  NS_IMETHOD_(void) WillDispatchKeyboardEvent(
-                      TextEventDispatcher* aTextEventDispatcher,
-                      WidgetKeyboardEvent& aKeyboardEvent,
-                      uint32_t aIndexOfKeypress,
-                      void* aData) override;
+  NS_IMETHOD_(void)
+  OnRemovedFrom(TextEventDispatcher* aTextEventDispatcher) override;
+  NS_IMETHOD_(void)
+  WillDispatchKeyboardEvent(TextEventDispatcher* aTextEventDispatcher,
+                            WidgetKeyboardEvent& aKeyboardEvent,
+                            uint32_t aIndexOfKeypress, void* aData) override;
 
-private:
+ private:
   nsresult Paint();
 
   void SetChild(PuppetWidget* aChild);
@@ -329,7 +311,8 @@ private:
   nsresult RequestIMEToCommitComposition(bool aCancel);
   nsresult NotifyIMEOfFocusChange(const IMENotification& aIMENotification);
   nsresult NotifyIMEOfSelectionChange(const IMENotification& aIMENotification);
-  nsresult NotifyIMEOfCompositionUpdate(const IMENotification& aIMENotification);
+  nsresult NotifyIMEOfCompositionUpdate(
+      const IMENotification& aIMENotification);
   nsresult NotifyIMEOfTextChange(const IMENotification& aIMENotification);
   nsresult NotifyIMEOfMouseButtonEvent(const IMENotification& aIMENotification);
   nsresult NotifyIMEOfPositionChange(const IMENotification& aIMENotification);
@@ -343,23 +326,29 @@ private:
 
   nsIWidgetListener* GetCurrentWidgetListener();
 
+  // When this widget caches input context and currently managed by
+  // IMEStateManager, the cache is valid.
+  bool HaveValidInputContextCache() const;
+
   class PaintTask : public Runnable {
-  public:
+   public:
     NS_DECL_NSIRUNNABLE
     explicit PaintTask(PuppetWidget* widget)
-     : Runnable("PuppetWidget::PaintTask"), mWidget(widget) {}
+        : Runnable("PuppetWidget::PaintTask"), mWidget(widget) {}
     void Revoke() { mWidget = nullptr; }
-  private:
+
+   private:
     PuppetWidget* mWidget;
   };
 
   class MemoryPressureObserver : public nsIObserver {
-  public:
+   public:
     NS_DECL_ISUPPORTS
     NS_DECL_NSIOBSERVER
     explicit MemoryPressureObserver(PuppetWidget* aWidget) : mWidget(aWidget) {}
     void Remove();
-  private:
+
+   private:
     virtual ~MemoryPressureObserver() {}
     PuppetWidget* mWidget;
   };
@@ -404,11 +393,11 @@ private:
 
   RefPtr<TextEventDispatcherListener> mNativeTextEventDispatcherListener;
 
-protected:
+ protected:
   bool mEnabled;
   bool mVisible;
 
-private:
+ private:
   bool mNeedIMEStateInit;
   // When remote process requests to commit/cancel a composition, the
   // composition may have already been committed in the main process.  In such
@@ -420,33 +409,33 @@ private:
   bool mIgnoreCompositionEvents;
 };
 
-class PuppetScreen : public nsBaseScreen
-{
-public:
-    explicit PuppetScreen(void* nativeScreen);
-    ~PuppetScreen();
+class PuppetScreen : public nsBaseScreen {
+ public:
+  explicit PuppetScreen(void* nativeScreen);
+  ~PuppetScreen();
 
-    NS_IMETHOD GetRect(int32_t* aLeft, int32_t* aTop, int32_t* aWidth, int32_t* aHeight) override;
-    NS_IMETHOD GetAvailRect(int32_t* aLeft, int32_t* aTop, int32_t* aWidth, int32_t* aHeight) override;
-    NS_IMETHOD GetPixelDepth(int32_t* aPixelDepth) override;
-    NS_IMETHOD GetColorDepth(int32_t* aColorDepth) override;
+  NS_IMETHOD GetRect(int32_t* aLeft, int32_t* aTop, int32_t* aWidth,
+                     int32_t* aHeight) override;
+  NS_IMETHOD GetAvailRect(int32_t* aLeft, int32_t* aTop, int32_t* aWidth,
+                          int32_t* aHeight) override;
+  NS_IMETHOD GetPixelDepth(int32_t* aPixelDepth) override;
+  NS_IMETHOD GetColorDepth(int32_t* aColorDepth) override;
 };
 
-class PuppetScreenManager final : public nsIScreenManager
-{
-    ~PuppetScreenManager();
+class PuppetScreenManager final : public nsIScreenManager {
+  ~PuppetScreenManager();
 
-public:
-    PuppetScreenManager();
+ public:
+  PuppetScreenManager();
 
-    NS_DECL_ISUPPORTS
-    NS_DECL_NSISCREENMANAGER
+  NS_DECL_ISUPPORTS
+  NS_DECL_NSISCREENMANAGER
 
-protected:
-    nsCOMPtr<nsIScreen> mOneScreen;
+ protected:
+  nsCOMPtr<nsIScreen> mOneScreen;
 };
 
-} // namespace widget
-} // namespace mozilla
+}  // namespace widget
+}  // namespace mozilla
 
 #endif  // mozilla_widget_PuppetWidget_h__
