@@ -11,7 +11,7 @@
 #include "mozilla/Assertions.h"
 #include "mozilla/BasicEvents.h"
 #include "mozilla/CheckedInt.h"
-#include "mozilla/EventForwards.h" // for KeyNameIndex, temporarily
+#include "mozilla/EventForwards.h"  // for KeyNameIndex, temporarily
 #include "mozilla/FontRange.h"
 #include "mozilla/TextRange.h"
 #include "mozilla/WritingModes.h"
@@ -25,14 +25,14 @@
 #include "nsTArray.h"
 
 class nsStringHashKey;
-template<class, class> class nsDataHashtable;
+template <class, class>
+class nsDataHashtable;
 
 /******************************************************************************
  * virtual keycode values
  ******************************************************************************/
 
-enum
-{
+enum {
 #define NS_DEFINE_VK(aDOMKeyName, aDOMKeyCode) NS_##aDOMKeyName = aDOMKeyCode,
 #include "mozilla/VirtualKeyCodeList.h"
 #undef NS_DEFINE_VK
@@ -41,26 +41,24 @@ enum
 
 namespace mozilla {
 
-enum : uint32_t
-{
+enum : uint32_t {
   eKeyLocationStandard = dom::KeyboardEventBinding::DOM_KEY_LOCATION_STANDARD,
-  eKeyLocationLeft     = dom::KeyboardEventBinding::DOM_KEY_LOCATION_LEFT,
-  eKeyLocationRight    = dom::KeyboardEventBinding::DOM_KEY_LOCATION_RIGHT,
-  eKeyLocationNumpad   = dom::KeyboardEventBinding::DOM_KEY_LOCATION_NUMPAD
+  eKeyLocationLeft = dom::KeyboardEventBinding::DOM_KEY_LOCATION_LEFT,
+  eKeyLocationRight = dom::KeyboardEventBinding::DOM_KEY_LOCATION_RIGHT,
+  eKeyLocationNumpad = dom::KeyboardEventBinding::DOM_KEY_LOCATION_NUMPAD
 };
 
 const nsCString GetDOMKeyCodeName(uint32_t aKeyCode);
 
 namespace dom {
-  class PBrowserParent;
-  class PBrowserChild;
-} // namespace dom
+class PBrowserParent;
+class PBrowserChild;
+}  // namespace dom
 namespace plugins {
-  class PPluginInstanceChild;
-} // namespace plugins
+class PPluginInstanceChild;
+}  // namespace plugins
 
-enum class AccessKeyType
-{
+enum class AccessKeyType {
   // Handle access key for chrome.
   eChrome,
   // Handle access key for content.
@@ -76,16 +74,11 @@ enum class AccessKeyType
  * The stored values proper for testing shortcut key or access key.
  ******************************************************************************/
 
-struct AlternativeCharCode
-{
-  AlternativeCharCode() :
-    mUnshiftedCharCode(0), mShiftedCharCode(0)
-  {
-  }
-  AlternativeCharCode(uint32_t aUnshiftedCharCode, uint32_t aShiftedCharCode) :
-    mUnshiftedCharCode(aUnshiftedCharCode), mShiftedCharCode(aShiftedCharCode)
-  {
-  }
+struct AlternativeCharCode {
+  AlternativeCharCode() : mUnshiftedCharCode(0), mShiftedCharCode(0) {}
+  AlternativeCharCode(uint32_t aUnshiftedCharCode, uint32_t aShiftedCharCode)
+      : mUnshiftedCharCode(aUnshiftedCharCode),
+        mShiftedCharCode(aShiftedCharCode) {}
   uint32_t mUnshiftedCharCode;
   uint32_t mShiftedCharCode;
 };
@@ -96,18 +89,10 @@ struct AlternativeCharCode
  * This stores a candidate of shortcut key combination.
  ******************************************************************************/
 
-struct ShortcutKeyCandidate
-{
-  ShortcutKeyCandidate()
-    : mCharCode(0)
-    , mIgnoreShift(0)
-  {
-  }
+struct ShortcutKeyCandidate {
+  ShortcutKeyCandidate() : mCharCode(0), mIgnoreShift(0) {}
   ShortcutKeyCandidate(uint32_t aCharCode, bool aIgnoreShift)
-    : mCharCode(aCharCode)
-    , mIgnoreShift(aIgnoreShift)
-  {
-  }
+      : mCharCode(aCharCode), mIgnoreShift(aIgnoreShift) {}
   // The mCharCode value which must match keyboard shortcut definition.
   uint32_t mCharCode;
   // true if Shift state can be ignored.  Otherwise, Shift key state must
@@ -122,82 +107,78 @@ struct ShortcutKeyCandidate
  * XBL handlers.
  ******************************************************************************/
 
-struct IgnoreModifierState
-{
+struct IgnoreModifierState {
   // When mShift is true, Shift key state will be ignored.
   bool mShift;
   // When mOS is true, OS key state will be ignored.
   bool mOS;
 
-  IgnoreModifierState()
-    : mShift(false)
-    , mOS(false)
-  {
-  }
+  IgnoreModifierState() : mShift(false), mOS(false) {}
 };
 
 /******************************************************************************
  * mozilla::WidgetKeyboardEvent
  ******************************************************************************/
 
-class WidgetKeyboardEvent : public WidgetInputEvent
-{
-private:
+class WidgetKeyboardEvent : public WidgetInputEvent {
+ private:
   friend class dom::PBrowserParent;
   friend class dom::PBrowserChild;
   friend struct IPC::ParamTraits<WidgetKeyboardEvent>;
 
-protected:
+ protected:
   WidgetKeyboardEvent()
-    : mNativeKeyEvent(nullptr)
-    , mKeyCode(0)
-    , mCharCode(0)
-    , mPseudoCharCode(0)
-    , mLocation(eKeyLocationStandard)
-    , mUniqueId(0)
+      : mNativeKeyEvent(nullptr),
+        mKeyCode(0),
+        mCharCode(0),
+        mPseudoCharCode(0),
+        mLocation(eKeyLocationStandard),
+        mUniqueId(0)
 #ifdef XP_MACOSX
-    , mNativeModifierFlags(0)
-    , mNativeKeyCode(0)
-#endif // #ifdef XP_MACOSX
-    , mKeyNameIndex(KEY_NAME_INDEX_Unidentified)
-    , mCodeNameIndex(CODE_NAME_INDEX_UNKNOWN)
-    , mIsRepeat(false)
-    , mIsComposing(false)
-    , mIsSynthesizedByTIP(false)
-    , mMaybeSkippableInRemoteProcess(true)
-    , mEditCommandsForSingleLineEditorInitialized(false)
-    , mEditCommandsForMultiLineEditorInitialized(false)
-    , mEditCommandsForRichTextEditorInitialized(false)
-  {
+        ,
+        mNativeModifierFlags(0),
+        mNativeKeyCode(0)
+#endif  // #ifdef XP_MACOSX
+        ,
+        mKeyNameIndex(KEY_NAME_INDEX_Unidentified),
+        mCodeNameIndex(CODE_NAME_INDEX_UNKNOWN),
+        mIsRepeat(false),
+        mIsComposing(false),
+        mIsSynthesizedByTIP(false),
+        mMaybeSkippableInRemoteProcess(true),
+        mEditCommandsForSingleLineEditorInitialized(false),
+        mEditCommandsForMultiLineEditorInitialized(false),
+        mEditCommandsForRichTextEditorInitialized(false) {
   }
 
-public:
+ public:
   virtual WidgetKeyboardEvent* AsKeyboardEvent() override { return this; }
 
   WidgetKeyboardEvent(bool aIsTrusted, EventMessage aMessage,
                       nsIWidget* aWidget,
                       EventClassID aEventClassID = eKeyboardEventClass)
-    : WidgetInputEvent(aIsTrusted, aMessage, aWidget, aEventClassID)
-    , mNativeKeyEvent(nullptr)
-    , mKeyCode(0)
-    , mCharCode(0)
-    , mPseudoCharCode(0)
-    , mLocation(eKeyLocationStandard)
-    , mUniqueId(0)
+      : WidgetInputEvent(aIsTrusted, aMessage, aWidget, aEventClassID),
+        mNativeKeyEvent(nullptr),
+        mKeyCode(0),
+        mCharCode(0),
+        mPseudoCharCode(0),
+        mLocation(eKeyLocationStandard),
+        mUniqueId(0)
 #ifdef XP_MACOSX
-    , mNativeModifierFlags(0)
-    , mNativeKeyCode(0)
-#endif // #ifdef XP_MACOSX
-    , mKeyNameIndex(KEY_NAME_INDEX_Unidentified)
-    , mCodeNameIndex(CODE_NAME_INDEX_UNKNOWN)
-    , mIsRepeat(false)
-    , mIsComposing(false)
-    , mIsSynthesizedByTIP(false)
-    , mMaybeSkippableInRemoteProcess(true)
-    , mEditCommandsForSingleLineEditorInitialized(false)
-    , mEditCommandsForMultiLineEditorInitialized(false)
-    , mEditCommandsForRichTextEditorInitialized(false)
-  {
+        ,
+        mNativeModifierFlags(0),
+        mNativeKeyCode(0)
+#endif  // #ifdef XP_MACOSX
+        ,
+        mKeyNameIndex(KEY_NAME_INDEX_Unidentified),
+        mCodeNameIndex(CODE_NAME_INDEX_UNKNOWN),
+        mIsRepeat(false),
+        mIsComposing(false),
+        mIsSynthesizedByTIP(false),
+        mMaybeSkippableInRemoteProcess(true),
+        mEditCommandsForSingleLineEditorInitialized(false),
+        mEditCommandsForMultiLineEditorInitialized(false),
+        mEditCommandsForRichTextEditorInitialized(false) {
     // If this is a keyboard event on a plugin, it shouldn't fired on content.
     if (IsKeyEventOnPlugin()) {
       mFlags.mOnlySystemGroupDispatchInContent = true;
@@ -205,52 +186,36 @@ public:
     }
   }
 
-  static bool IsKeyDownOrKeyDownOnPlugin(EventMessage aMessage)
-  {
+  static bool IsKeyDownOrKeyDownOnPlugin(EventMessage aMessage) {
     return aMessage == eKeyDown || aMessage == eKeyDownOnPlugin;
   }
-  bool IsKeyDownOrKeyDownOnPlugin() const
-  {
+  bool IsKeyDownOrKeyDownOnPlugin() const {
     return IsKeyDownOrKeyDownOnPlugin(mMessage);
   }
-  static bool IsKeyUpOrKeyUpOnPlugin(EventMessage aMessage)
-  {
+  static bool IsKeyUpOrKeyUpOnPlugin(EventMessage aMessage) {
     return aMessage == eKeyUp || aMessage == eKeyUpOnPlugin;
   }
-  bool IsKeyUpOrKeyUpOnPlugin() const
-  {
+  bool IsKeyUpOrKeyUpOnPlugin() const {
     return IsKeyUpOrKeyUpOnPlugin(mMessage);
   }
-  static bool IsKeyEventOnPlugin(EventMessage aMessage)
-  {
+  static bool IsKeyEventOnPlugin(EventMessage aMessage) {
     return aMessage == eKeyDownOnPlugin || aMessage == eKeyUpOnPlugin;
   }
-  bool IsKeyEventOnPlugin() const
-  {
-    return IsKeyEventOnPlugin(mMessage);
-  }
+  bool IsKeyEventOnPlugin() const { return IsKeyEventOnPlugin(mMessage); }
 
-  bool IsInputtingText() const
-  {
+  bool IsInputtingText() const {
     // NOTE: On some keyboard layout, some characters are inputted with Control
     //       key or Alt key, but at that time, widget unset the modifier flag
     //       from eKeyPress event.
-    return mMessage == eKeyPress &&
-           mCharCode &&
-           !(mModifiers & (MODIFIER_ALT |
-                           MODIFIER_CONTROL |
-                           MODIFIER_META |
-                           MODIFIER_OS));
+    return mMessage == eKeyPress && mCharCode &&
+           !(mModifiers &
+             (MODIFIER_ALT | MODIFIER_CONTROL | MODIFIER_META | MODIFIER_OS));
   }
 
-  bool IsInputtingLineBreak() const
-  {
-    return mMessage == eKeyPress &&
-           mKeyNameIndex == KEY_NAME_INDEX_Enter &&
-           !(mModifiers & (MODIFIER_ALT |
-                           MODIFIER_CONTROL |
-                           MODIFIER_META |
-                           MODIFIER_OS));
+  bool IsInputtingLineBreak() const {
+    return mMessage == eKeyPress && mKeyNameIndex == KEY_NAME_INDEX_Enter &&
+           !(mModifiers &
+             (MODIFIER_ALT | MODIFIER_CONTROL | MODIFIER_META | MODIFIER_OS));
   }
 
   /**
@@ -258,8 +223,7 @@ public:
    * instance is eKeyPress event.  This returns true when the eKeyPress
    * event should be fired even on content in the default event group.
    */
-  bool ShouldKeyPressEventBeFiredOnContent() const
-  {
+  bool ShouldKeyPressEventBeFiredOnContent() const {
     MOZ_DIAGNOSTIC_ASSERT(mMessage == eKeyPress);
     if (IsInputtingText() || IsInputtingLineBreak()) {
       return true;
@@ -268,21 +232,17 @@ public:
     // However, the other browsers fire keypress event in any platforms.
     // So, for compatibility with them, we should fire keypress event for
     // Ctrl + Enter too.
-    return mMessage == eKeyPress &&
-           mKeyNameIndex == KEY_NAME_INDEX_Enter &&
-           !(mModifiers & (MODIFIER_ALT |
-                           MODIFIER_META |
-                           MODIFIER_OS |
-                           MODIFIER_SHIFT));
+    return mMessage == eKeyPress && mKeyNameIndex == KEY_NAME_INDEX_Enter &&
+           !(mModifiers &
+             (MODIFIER_ALT | MODIFIER_META | MODIFIER_OS | MODIFIER_SHIFT));
   }
 
-  virtual WidgetEvent* Duplicate() const override
-  {
+  virtual WidgetEvent* Duplicate() const override {
     MOZ_ASSERT(mClass == eKeyboardEventClass,
                "Duplicate() must be overridden by sub class");
     // Not copying widget, it is a weak reference.
     WidgetKeyboardEvent* result =
-      new WidgetKeyboardEvent(false, mMessage, nullptr);
+        new WidgetKeyboardEvent(false, mMessage, nullptr);
     result->AssignKeyEventData(*this, true);
     result->mEditCommandsForSingleLineEditor = mEditCommandsForSingleLineEditor;
     result->mEditCommandsForMultiLineEditor = mEditCommandsForMultiLineEditor;
@@ -307,7 +267,7 @@ public:
   // If this is non-empty, create a text event for plugins instead of a
   // keyboard event.
   nsString mPluginTextEventString;
-#endif // #ifdef XP_MACOSX
+#endif  // #ifdef XP_MACOSX
 
   // OS-specific native event can optionally be preserved
   void* mNativeKeyEvent;
@@ -333,7 +293,7 @@ public:
   // Values given by a native NSEvent, for use with Cocoa NPAPI plugins.
   uint32_t mNativeModifierFlags;
   uint16_t mNativeKeyCode;
-#endif // #ifdef XP_MACOSX
+#endif  // #ifdef XP_MACOSX
 
   // DOM KeyboardEvent.key
   KeyNameIndex mKeyNameIndex;
@@ -355,8 +315,7 @@ public:
   // Use CanSkipInRemoteProcess() instead.
   bool mMaybeSkippableInRemoteProcess;
 
-  bool CanSkipInRemoteProcess() const
-  {
+  bool CanSkipInRemoteProcess() const {
     // If this is a repeat event (i.e., generated by auto-repeat feature of
     // the platform), remove process may skip to handle it because of
     // performances reasons..  However, if it's caused by odd keyboard utils,
@@ -387,8 +346,7 @@ public:
    * PreventNativeKeyBindings() makes the instance to not cause any edit
    * actions even if it matches with a native key binding.
    */
-  void PreventNativeKeyBindings()
-  {
+  void PreventNativeKeyBindings() {
     mEditCommandsForSingleLineEditor.Clear();
     mEditCommandsForMultiLineEditor.Clear();
     mEditCommandsForRichTextEditor.Clear();
@@ -400,9 +358,8 @@ public:
   /**
    * EditCommandsConstRef() returns reference to edit commands for aType.
    */
-  const nsTArray<CommandInt>&
-    EditCommandsConstRef(nsIWidget::NativeKeyBindingsType aType) const
-  {
+  const nsTArray<CommandInt>& EditCommandsConstRef(
+      nsIWidget::NativeKeyBindingsType aType) const {
     return const_cast<WidgetKeyboardEvent*>(this)->EditCommandsRef(aType);
   }
 
@@ -410,11 +367,9 @@ public:
    * IsEditCommandsInitialized() returns true if edit commands for aType
    * was already initialized.  Otherwise, false.
    */
-  bool IsEditCommandsInitialized(
-         nsIWidget::NativeKeyBindingsType aType) const
-  {
-    return const_cast<WidgetKeyboardEvent*>(this)->
-             IsEditCommandsInitializedRef(aType);
+  bool IsEditCommandsInitialized(nsIWidget::NativeKeyBindingsType aType) const {
+    return const_cast<WidgetKeyboardEvent*>(this)->IsEditCommandsInitializedRef(
+        aType);
   }
 
 #ifdef DEBUG
@@ -422,13 +377,12 @@ public:
    * AreAllEditCommandsInitialized() returns true if edit commands for all
    * types were already initialized.  Otherwise, false.
    */
-  bool AreAllEditCommandsInitialized() const
-  {
+  bool AreAllEditCommandsInitialized() const {
     return mEditCommandsForSingleLineEditorInitialized &&
            mEditCommandsForMultiLineEditorInitialized &&
            mEditCommandsForRichTextEditorInitialized;
   }
-#endif // #ifdef DEBUG
+#endif  // #ifdef DEBUG
 
   /**
    * Execute edit commands for aType.
@@ -438,8 +392,7 @@ public:
    */
   typedef void (*DoCommandCallback)(Command, void*);
   bool ExecuteEditCommands(nsIWidget::NativeKeyBindingsType aType,
-                           DoCommandCallback aCallback,
-                           void* aCallbackData);
+                           DoCommandCallback aCallback, void* aCallbackData);
 
   // If the key should cause keypress events, this returns true.
   // Otherwise, false.
@@ -450,12 +403,10 @@ public:
   // its first item should be the mCharCode value of following eKeyPress event.
   // PseudoCharCode() returns mCharCode value for eKeyPress event,
   // the first alternative char code value of non-eKeyPress event or 0.
-  uint32_t PseudoCharCode() const
-  {
+  uint32_t PseudoCharCode() const {
     return mMessage == eKeyPress ? mCharCode : mPseudoCharCode;
   }
-  void SetCharCode(uint32_t aCharCode)
-  {
+  void SetCharCode(uint32_t aCharCode) {
     if (mMessage == eKeyPress) {
       mCharCode = aCharCode;
     } else {
@@ -463,16 +414,14 @@ public:
     }
   }
 
-  void GetDOMKeyName(nsAString& aKeyName)
-  {
+  void GetDOMKeyName(nsAString& aKeyName) {
     if (mKeyNameIndex == KEY_NAME_INDEX_USE_STRING) {
       aKeyName = mKeyValue;
       return;
     }
     GetDOMKeyName(mKeyNameIndex, aKeyName);
   }
-  void GetDOMCodeName(nsAString& aCodeName)
-  {
+  void GetDOMCodeName(nsAString& aCodeName) {
     if (mCodeNameIndex == CODE_NAME_INDEX_USE_STRING) {
       aCodeName = mCodeValue;
       return;
@@ -488,11 +437,10 @@ public:
    * if the key doesn't produce ASCII character with active keyboard layout
    * nor with alternative ASCII capable keyboard layout.
    */
-  static uint32_t
-  GetFallbackKeyCodeOfPunctuationKey(CodeNameIndex aCodeNameIndex);
+  static uint32_t GetFallbackKeyCodeOfPunctuationKey(
+      CodeNameIndex aCodeNameIndex);
 
-  bool IsModifierKeyEvent() const
-  {
+  bool IsModifierKeyEvent() const {
     return GetModifierForKeyName(mKeyNameIndex) != MODIFIER_NONE;
   }
 
@@ -559,8 +507,7 @@ public:
    */
   static bool IsLockableModifier(KeyNameIndex aKeyNameIndex);
 
-  static void GetDOMKeyName(KeyNameIndex aKeyNameIndex,
-                            nsAString& aKeyName);
+  static void GetDOMKeyName(KeyNameIndex aKeyNameIndex, nsAString& aKeyName);
   static void GetDOMCodeName(CodeNameIndex aCodeNameIndex,
                              nsAString& aCodeName);
 
@@ -569,8 +516,8 @@ public:
 
   static const char* GetCommandStr(Command aCommand);
 
-  void AssignKeyEventData(const WidgetKeyboardEvent& aEvent, bool aCopyTargets)
-  {
+  void AssignKeyEventData(const WidgetKeyboardEvent& aEvent,
+                          bool aCopyTargets) {
     AssignInputEventData(aEvent, aCopyTargets);
 
     mKeyCode = aEvent.mKeyCode;
@@ -592,8 +539,8 @@ public:
     mNativeKeyCode = aEvent.mNativeKeyCode;
     mNativeModifierFlags = aEvent.mNativeModifierFlags;
     mNativeCharacters.Assign(aEvent.mNativeCharacters);
-    mNativeCharactersIgnoringModifiers.
-      Assign(aEvent.mNativeCharactersIgnoringModifiers);
+    mNativeCharactersIgnoringModifiers.Assign(
+        aEvent.mNativeCharactersIgnoringModifiers);
     mPluginTextEventString.Assign(aEvent.mPluginTextEventString);
 #endif
     mIsSynthesizedByTIP = aEvent.mIsSynthesizedByTIP;
@@ -604,20 +551,19 @@ public:
     // a JS variable, they are not necessary anymore.
 
     mEditCommandsForSingleLineEditorInitialized =
-      aEvent.mEditCommandsForSingleLineEditorInitialized;
+        aEvent.mEditCommandsForSingleLineEditorInitialized;
     mEditCommandsForMultiLineEditorInitialized =
-      aEvent.mEditCommandsForMultiLineEditorInitialized;
+        aEvent.mEditCommandsForMultiLineEditorInitialized;
     mEditCommandsForRichTextEditorInitialized =
-      aEvent.mEditCommandsForRichTextEditorInitialized;
+        aEvent.mEditCommandsForRichTextEditorInitialized;
   }
 
-private:
+ private:
   static const char16_t* const kKeyNames[];
   static const char16_t* const kCodeNames[];
-  typedef nsDataHashtable<nsStringHashKey,
-                          KeyNameIndex> KeyNameIndexHashtable;
-  typedef nsDataHashtable<nsStringHashKey,
-                          CodeNameIndex> CodeNameIndexHashtable;
+  typedef nsDataHashtable<nsStringHashKey, KeyNameIndex> KeyNameIndexHashtable;
+  typedef nsDataHashtable<nsStringHashKey, CodeNameIndex>
+      CodeNameIndexHashtable;
   static KeyNameIndexHashtable* sKeyNameIndexHashtable;
   static CodeNameIndexHashtable* sCodeNameIndexHashtable;
 
@@ -629,8 +575,8 @@ private:
   nsTArray<CommandInt> mEditCommandsForMultiLineEditor;
   nsTArray<CommandInt> mEditCommandsForRichTextEditor;
 
-  nsTArray<CommandInt>& EditCommandsRef(nsIWidget::NativeKeyBindingsType aType)
-  {
+  nsTArray<CommandInt>& EditCommandsRef(
+      nsIWidget::NativeKeyBindingsType aType) {
     switch (aType) {
       case nsIWidget::NativeKeyBindingsForSingleLineEditor:
         return mEditCommandsForSingleLineEditor;
@@ -640,7 +586,7 @@ private:
         return mEditCommandsForRichTextEditor;
       default:
         MOZ_MAKE_COMPILER_ASSUME_IS_UNREACHABLE(
-          "Invalid native key binding type");
+            "Invalid native key binding type");
     }
   }
 
@@ -650,8 +596,7 @@ private:
   bool mEditCommandsForMultiLineEditorInitialized;
   bool mEditCommandsForRichTextEditorInitialized;
 
-  bool& IsEditCommandsInitializedRef(nsIWidget::NativeKeyBindingsType aType)
-  {
+  bool& IsEditCommandsInitializedRef(nsIWidget::NativeKeyBindingsType aType) {
     switch (aType) {
       case nsIWidget::NativeKeyBindingsForSingleLineEditor:
         return mEditCommandsForSingleLineEditorInitialized;
@@ -661,7 +606,7 @@ private:
         return mEditCommandsForRichTextEditorInitialized;
       default:
         MOZ_MAKE_COMPILER_ASSUME_IS_UNREACHABLE(
-          "Invalid native key binding type");
+            "Invalid native key binding type");
     }
   }
 
@@ -674,37 +619,28 @@ private:
  * mozilla::WidgetCompositionEvent
  ******************************************************************************/
 
-class WidgetCompositionEvent : public WidgetGUIEvent
-{
-private:
+class WidgetCompositionEvent : public WidgetGUIEvent {
+ private:
   friend class mozilla::dom::PBrowserParent;
   friend class mozilla::dom::PBrowserChild;
 
-  WidgetCompositionEvent()
-  {
-  }
+  WidgetCompositionEvent() {}
 
-public:
-  virtual WidgetCompositionEvent* AsCompositionEvent() override
-  {
-    return this;
-  }
+ public:
+  virtual WidgetCompositionEvent* AsCompositionEvent() override { return this; }
 
   WidgetCompositionEvent(bool aIsTrusted, EventMessage aMessage,
                          nsIWidget* aWidget)
-    : WidgetGUIEvent(aIsTrusted, aMessage, aWidget, eCompositionEventClass)
-    , mNativeIMEContext(aWidget)
-    , mOriginalMessage(eVoidEvent)
-  {
-  }
+      : WidgetGUIEvent(aIsTrusted, aMessage, aWidget, eCompositionEventClass),
+        mNativeIMEContext(aWidget),
+        mOriginalMessage(eVoidEvent) {}
 
-  virtual WidgetEvent* Duplicate() const override
-  {
+  virtual WidgetEvent* Duplicate() const override {
     MOZ_ASSERT(mClass == eCompositionEventClass,
                "Duplicate() must be overridden by sub class");
     // Not copying widget, it is a weak reference.
     WidgetCompositionEvent* result =
-      new WidgetCompositionEvent(false, mMessage, nullptr);
+        new WidgetCompositionEvent(false, mMessage, nullptr);
     result->AssignCompositionEventData(*this, true);
     result->mFlags = mFlags;
     return result;
@@ -726,8 +662,7 @@ public:
   EventMessage mOriginalMessage;
 
   void AssignCompositionEventData(const WidgetCompositionEvent& aEvent,
-                                  bool aCopyTargets)
-  {
+                                  bool aCopyTargets) {
     AssignGUIEventData(aEvent, aCopyTargets);
 
     mData = aEvent.mData;
@@ -738,18 +673,13 @@ public:
     // for internal use only (not available from JS).
   }
 
-  bool IsComposing() const
-  {
-    return mRanges && mRanges->IsComposing();
-  }
+  bool IsComposing() const { return mRanges && mRanges->IsComposing(); }
 
-  uint32_t TargetClauseOffset() const
-  {
+  uint32_t TargetClauseOffset() const {
     return mRanges ? mRanges->TargetClauseOffset() : 0;
   }
 
-  uint32_t TargetClauseLength() const
-  {
+  uint32_t TargetClauseLength() const {
     uint32_t length = UINT32_MAX;
     if (mRanges) {
       length = mRanges->TargetClauseLength();
@@ -757,32 +687,23 @@ public:
     return length == UINT32_MAX ? mData.Length() : length;
   }
 
-  uint32_t RangeCount() const
-  {
-    return mRanges ? mRanges->Length() : 0;
-  }
+  uint32_t RangeCount() const { return mRanges ? mRanges->Length() : 0; }
 
-  bool CausesDOMTextEvent() const
-  {
-    return mMessage == eCompositionChange ||
-           mMessage == eCompositionCommit ||
+  bool CausesDOMTextEvent() const {
+    return mMessage == eCompositionChange || mMessage == eCompositionCommit ||
            mMessage == eCompositionCommitAsIs;
   }
 
-  bool CausesDOMCompositionEndEvent() const
-  {
-    return mMessage == eCompositionEnd ||
-           mMessage == eCompositionCommit ||
+  bool CausesDOMCompositionEndEvent() const {
+    return mMessage == eCompositionEnd || mMessage == eCompositionCommit ||
            mMessage == eCompositionCommitAsIs;
   }
 
-  bool IsFollowedByCompositionEnd() const
-  {
+  bool IsFollowedByCompositionEnd() const {
     return IsFollowedByCompositionEnd(mOriginalMessage);
   }
 
-  static bool IsFollowedByCompositionEnd(EventMessage aEventMessage)
-  {
+  static bool IsFollowedByCompositionEnd(EventMessage aEventMessage) {
     return aEventMessage == eCompositionCommit ||
            aEventMessage == eCompositionCommitAsIs;
   }
@@ -792,84 +713,65 @@ public:
  * mozilla::WidgetQueryContentEvent
  ******************************************************************************/
 
-class WidgetQueryContentEvent : public WidgetGUIEvent
-{
-private:
+class WidgetQueryContentEvent : public WidgetGUIEvent {
+ private:
   friend class dom::PBrowserParent;
   friend class dom::PBrowserChild;
 
   WidgetQueryContentEvent()
-    : mSucceeded(false)
-    , mUseNativeLineBreak(true)
-    , mWithFontRanges(false)
-  {
+      : mSucceeded(false), mUseNativeLineBreak(true), mWithFontRanges(false) {
     MOZ_CRASH("WidgetQueryContentEvent is created without proper arguments");
   }
 
-public:
-  virtual WidgetQueryContentEvent* AsQueryContentEvent() override
-  {
+ public:
+  virtual WidgetQueryContentEvent* AsQueryContentEvent() override {
     return this;
   }
 
   WidgetQueryContentEvent(bool aIsTrusted, EventMessage aMessage,
                           nsIWidget* aWidget)
-    : WidgetGUIEvent(aIsTrusted, aMessage, aWidget, eQueryContentEventClass)
-    , mSucceeded(false)
-    , mUseNativeLineBreak(true)
-    , mWithFontRanges(false)
-  {
-  }
+      : WidgetGUIEvent(aIsTrusted, aMessage, aWidget, eQueryContentEventClass),
+        mSucceeded(false),
+        mUseNativeLineBreak(true),
+        mWithFontRanges(false) {}
 
   WidgetQueryContentEvent(EventMessage aMessage,
                           const WidgetQueryContentEvent& aOtherEvent)
-    : WidgetGUIEvent(aOtherEvent.IsTrusted(), aMessage,
-                     const_cast<nsIWidget*>(aOtherEvent.mWidget.get()),
-                     eQueryContentEventClass)
-    , mSucceeded(false)
-    , mUseNativeLineBreak(aOtherEvent.mUseNativeLineBreak)
-    , mWithFontRanges(false)
-  {
-  }
+      : WidgetGUIEvent(aOtherEvent.IsTrusted(), aMessage,
+                       const_cast<nsIWidget*>(aOtherEvent.mWidget.get()),
+                       eQueryContentEventClass),
+        mSucceeded(false),
+        mUseNativeLineBreak(aOtherEvent.mUseNativeLineBreak),
+        mWithFontRanges(false) {}
 
-  virtual WidgetEvent* Duplicate() const override
-  {
+  virtual WidgetEvent* Duplicate() const override {
     // This event isn't an internal event of any DOM event.
     NS_ASSERTION(!IsAllowedToDispatchDOMEvent(),
-      "WidgetQueryContentEvent needs to support Duplicate()");
+                 "WidgetQueryContentEvent needs to support Duplicate()");
     MOZ_CRASH("WidgetQueryContentEvent doesn't support Duplicate()");
   }
 
-  struct Options final
-  {
+  struct Options final {
     bool mUseNativeLineBreak;
     bool mRelativeToInsertionPoint;
 
     explicit Options()
-      : mUseNativeLineBreak(true)
-      , mRelativeToInsertionPoint(false)
-    {
-    }
+        : mUseNativeLineBreak(true), mRelativeToInsertionPoint(false) {}
 
     explicit Options(const WidgetQueryContentEvent& aEvent)
-      : mUseNativeLineBreak(aEvent.mUseNativeLineBreak)
-      , mRelativeToInsertionPoint(aEvent.mInput.mRelativeToInsertionPoint)
-    {
-    }
+        : mUseNativeLineBreak(aEvent.mUseNativeLineBreak),
+          mRelativeToInsertionPoint(aEvent.mInput.mRelativeToInsertionPoint) {}
   };
 
-  void Init(const Options& aOptions)
-  {
+  void Init(const Options& aOptions) {
     mUseNativeLineBreak = aOptions.mUseNativeLineBreak;
     mInput.mRelativeToInsertionPoint = aOptions.mRelativeToInsertionPoint;
     MOZ_ASSERT(mInput.IsValidEventMessage(mMessage));
   }
 
   void InitForQueryTextContent(int64_t aOffset, uint32_t aLength,
-                               const Options& aOptions = Options())
-  {
-    NS_ASSERTION(mMessage == eQueryTextContent,
-                 "wrong initializer is called");
+                               const Options& aOptions = Options()) {
+    NS_ASSERTION(mMessage == eQueryTextContent, "wrong initializer is called");
     mInput.mOffset = aOffset;
     mInput.mLength = aLength;
     Init(aOptions);
@@ -877,20 +779,16 @@ public:
   }
 
   void InitForQueryCaretRect(int64_t aOffset,
-                             const Options& aOptions = Options())
-  {
-    NS_ASSERTION(mMessage == eQueryCaretRect,
-                 "wrong initializer is called");
+                             const Options& aOptions = Options()) {
+    NS_ASSERTION(mMessage == eQueryCaretRect, "wrong initializer is called");
     mInput.mOffset = aOffset;
     Init(aOptions);
     MOZ_ASSERT(mInput.IsValidOffset());
   }
 
   void InitForQueryTextRect(int64_t aOffset, uint32_t aLength,
-                            const Options& aOptions = Options())
-  {
-    NS_ASSERTION(mMessage == eQueryTextRect,
-                 "wrong initializer is called");
+                            const Options& aOptions = Options()) {
+    NS_ASSERTION(mMessage == eQueryTextRect, "wrong initializer is called");
     mInput.mOffset = aOffset;
     mInput.mLength = aLength;
     Init(aOptions);
@@ -898,24 +796,22 @@ public:
   }
 
   void InitForQuerySelectedText(SelectionType aSelectionType,
-                                const Options& aOptions = Options())
-  {
+                                const Options& aOptions = Options()) {
     MOZ_ASSERT(mMessage == eQuerySelectedText);
     MOZ_ASSERT(aSelectionType != SelectionType::eNone);
     mInput.mSelectionType = aSelectionType;
     Init(aOptions);
   }
 
-  void InitForQueryDOMWidgetHittest(const mozilla::LayoutDeviceIntPoint& aPoint)
-  {
+  void InitForQueryDOMWidgetHittest(
+      const mozilla::LayoutDeviceIntPoint& aPoint) {
     NS_ASSERTION(mMessage == eQueryDOMWidgetHittest,
                  "wrong initializer is called");
     mRefPoint = aPoint;
   }
 
   void InitForQueryTextRectArray(uint32_t aOffset, uint32_t aLength,
-                                 const Options& aOptions = Options())
-  {
+                                 const Options& aOptions = Options()) {
     NS_ASSERTION(mMessage == eQueryTextRectArray,
                  "wrong initializer is called");
     mInput.mOffset = aOffset;
@@ -923,32 +819,24 @@ public:
     Init(aOptions);
   }
 
-  void RequestFontRanges()
-  {
-    NS_ASSERTION(mMessage == eQueryTextContent,
-                 "not querying text content");
+  void RequestFontRanges() {
+    NS_ASSERTION(mMessage == eQueryTextContent, "not querying text content");
     mWithFontRanges = true;
   }
 
-  uint32_t GetSelectionStart(void) const
-  {
-    NS_ASSERTION(mMessage == eQuerySelectedText,
-                 "not querying selection");
+  uint32_t GetSelectionStart(void) const {
+    NS_ASSERTION(mMessage == eQuerySelectedText, "not querying selection");
     return mReply.mOffset + (mReply.mReversed ? mReply.mString.Length() : 0);
   }
 
-  uint32_t GetSelectionEnd(void) const
-  {
-    NS_ASSERTION(mMessage == eQuerySelectedText,
-                 "not querying selection");
+  uint32_t GetSelectionEnd(void) const {
+    NS_ASSERTION(mMessage == eQuerySelectedText, "not querying selection");
     return mReply.mOffset + (mReply.mReversed ? 0 : mReply.mString.Length());
   }
 
-  mozilla::WritingMode GetWritingMode(void) const
-  {
+  mozilla::WritingMode GetWritingMode(void) const {
     NS_ASSERTION(mMessage == eQuerySelectedText ||
-                 mMessage == eQueryCaretRect ||
-                 mMessage == eQueryTextRect,
+                     mMessage == eQueryCaretRect || mMessage == eQueryTextRect,
                  "not querying selection or text rect");
     return mReply.mWritingMode;
   }
@@ -956,12 +844,9 @@ public:
   bool mSucceeded;
   bool mUseNativeLineBreak;
   bool mWithFontRanges;
-  struct Input final
-  {
-    uint32_t EndOffset() const
-    {
-      CheckedInt<uint32_t> endOffset =
-        CheckedInt<uint32_t>(mOffset) + mLength;
+  struct Input final {
+    uint32_t EndOffset() const {
+      CheckedInt<uint32_t> endOffset = CheckedInt<uint32_t>(mOffset) + mLength;
       return NS_WARN_IF(!endOffset.isValid()) ? UINT32_MAX : endOffset.value();
     }
 
@@ -974,19 +859,15 @@ public:
     bool mRelativeToInsertionPoint;
 
     Input()
-      : mOffset(0)
-      , mLength(0)
-      , mSelectionType(SelectionType::eNormal)
-      , mRelativeToInsertionPoint(false)
-    {
-    }
+        : mOffset(0),
+          mLength(0),
+          mSelectionType(SelectionType::eNormal),
+          mRelativeToInsertionPoint(false) {}
 
-    bool IsValidOffset() const
-    {
+    bool IsValidOffset() const {
       return mRelativeToInsertionPoint || mOffset >= 0;
     }
-    bool IsValidEventMessage(EventMessage aEventMessage) const
-    {
+    bool IsValidEventMessage(EventMessage aEventMessage) const {
       if (!mRelativeToInsertionPoint) {
         return true;
       }
@@ -999,8 +880,7 @@ public:
           return false;
       }
     }
-    bool MakeOffsetAbsolute(uint32_t aInsertionPointOffset)
-    {
+    bool MakeOffsetAbsolute(uint32_t aInsertionPointOffset) {
       if (NS_WARN_IF(!mRelativeToInsertionPoint)) {
         return true;
       }
@@ -1022,8 +902,7 @@ public:
     }
   } mInput;
 
-  struct Reply final
-  {
+  struct Reply final {
     void* mContentsRoot;
     uint32_t mOffset;
     // mTentativeCaretOffset is used by only eQueryCharacterAtPoint.
@@ -1054,75 +933,56 @@ public:
     bool mWidgetIsHit;
 
     Reply()
-      : mContentsRoot(nullptr)
-      , mOffset(NOT_FOUND)
-      , mTentativeCaretOffset(NOT_FOUND)
-      , mFocusedWidget(nullptr)
-      , mReversed(false)
-      , mHasSelection(false)
-      , mWidgetIsHit(false)
-    {
-    }
+        : mContentsRoot(nullptr),
+          mOffset(NOT_FOUND),
+          mTentativeCaretOffset(NOT_FOUND),
+          mFocusedWidget(nullptr),
+          mReversed(false),
+          mHasSelection(false),
+          mWidgetIsHit(false) {}
   } mReply;
 
-  enum
-  {
-    NOT_FOUND = UINT32_MAX
-  };
+  enum { NOT_FOUND = UINT32_MAX };
 
   // values of mComputedScrollAction
-  enum
-  {
-    SCROLL_ACTION_NONE,
-    SCROLL_ACTION_LINE,
-    SCROLL_ACTION_PAGE
-  };
+  enum { SCROLL_ACTION_NONE, SCROLL_ACTION_LINE, SCROLL_ACTION_PAGE };
 };
 
 /******************************************************************************
  * mozilla::WidgetSelectionEvent
  ******************************************************************************/
 
-class WidgetSelectionEvent : public WidgetGUIEvent
-{
-private:
+class WidgetSelectionEvent : public WidgetGUIEvent {
+ private:
   friend class mozilla::dom::PBrowserParent;
   friend class mozilla::dom::PBrowserChild;
 
   WidgetSelectionEvent()
-    : mOffset(0)
-    , mLength(0)
-    , mReversed(false)
-    , mExpandToClusterBoundary(true)
-    , mSucceeded(false)
-    , mUseNativeLineBreak(true)
-  {
-  }
+      : mOffset(0),
+        mLength(0),
+        mReversed(false),
+        mExpandToClusterBoundary(true),
+        mSucceeded(false),
+        mUseNativeLineBreak(true) {}
 
-public:
-  virtual WidgetSelectionEvent* AsSelectionEvent() override
-  {
-    return this;
-  }
+ public:
+  virtual WidgetSelectionEvent* AsSelectionEvent() override { return this; }
 
   WidgetSelectionEvent(bool aIsTrusted, EventMessage aMessage,
                        nsIWidget* aWidget)
-    : WidgetGUIEvent(aIsTrusted, aMessage, aWidget, eSelectionEventClass)
-    , mOffset(0)
-    , mLength(0)
-    , mReversed(false)
-    , mExpandToClusterBoundary(true)
-    , mSucceeded(false)
-    , mUseNativeLineBreak(true)
-    , mReason(nsISelectionListener::NO_REASON)
-  {
-  }
+      : WidgetGUIEvent(aIsTrusted, aMessage, aWidget, eSelectionEventClass),
+        mOffset(0),
+        mLength(0),
+        mReversed(false),
+        mExpandToClusterBoundary(true),
+        mSucceeded(false),
+        mUseNativeLineBreak(true),
+        mReason(nsISelectionListener::NO_REASON) {}
 
-  virtual WidgetEvent* Duplicate() const override
-  {
+  virtual WidgetEvent* Duplicate() const override {
     // This event isn't an internal event of any DOM event.
     NS_ASSERTION(!IsAllowedToDispatchDOMEvent(),
-      "WidgetSelectionEvent needs to support Duplicate()");
+                 "WidgetSelectionEvent needs to support Duplicate()");
     MOZ_CRASH("WidgetSelectionEvent doesn't support Duplicate()");
     return nullptr;
   }
@@ -1148,34 +1008,26 @@ public:
  * mozilla::InternalEditorInputEvent
  ******************************************************************************/
 
-class InternalEditorInputEvent : public InternalUIEvent
-{
-private:
-  InternalEditorInputEvent()
-    : mIsComposing(false)
-  {
-  }
+class InternalEditorInputEvent : public InternalUIEvent {
+ private:
+  InternalEditorInputEvent() : mIsComposing(false) {}
 
-public:
-  virtual InternalEditorInputEvent* AsEditorInputEvent() override
-  {
+ public:
+  virtual InternalEditorInputEvent* AsEditorInputEvent() override {
     return this;
   }
 
   InternalEditorInputEvent(bool aIsTrusted, EventMessage aMessage,
                            nsIWidget* aWidget = nullptr)
-    : InternalUIEvent(aIsTrusted, aMessage, aWidget, eEditorInputEventClass)
-    , mIsComposing(false)
-  {
-  }
+      : InternalUIEvent(aIsTrusted, aMessage, aWidget, eEditorInputEventClass),
+        mIsComposing(false) {}
 
-  virtual WidgetEvent* Duplicate() const override
-  {
+  virtual WidgetEvent* Duplicate() const override {
     MOZ_ASSERT(mClass == eEditorInputEventClass,
                "Duplicate() must be overridden by sub class");
     // Not copying widget, it is a weak reference.
     InternalEditorInputEvent* result =
-      new InternalEditorInputEvent(false, mMessage, nullptr);
+        new InternalEditorInputEvent(false, mMessage, nullptr);
     result->AssignEditorInputEventData(*this, true);
     result->mFlags = mFlags;
     return result;
@@ -1184,14 +1036,13 @@ public:
   bool mIsComposing;
 
   void AssignEditorInputEventData(const InternalEditorInputEvent& aEvent,
-                                  bool aCopyTargets)
-  {
+                                  bool aCopyTargets) {
     AssignUIEventData(aEvent, aCopyTargets);
 
     mIsComposing = aEvent.mIsComposing;
   }
 };
 
-} // namespace mozilla
+}  // namespace mozilla
 
-#endif // mozilla_TextEvents_h__
+#endif  // mozilla_TextEvents_h__
