@@ -17,21 +17,24 @@ namespace widget {
 // the most part it only requires an HWND, however it maintains extra state
 // for transparent windows, as well as for synchronizing WM_SETTEXT messages
 // with the compositor.
-class InProcessWinCompositorWidget final : public WinCompositorWidget
-{
-public:
+class InProcessWinCompositorWidget final : public WinCompositorWidget {
+ public:
   InProcessWinCompositorWidget(const WinCompositorWidgetInitData& aInitData,
                                const layers::CompositorOptions& aOptions,
                                nsWindow* aWindow);
 
+  void OnDestroyWindow() override;
+  void UpdateTransparency(nsTransparencyMode aMode) override;
+  void ClearTransparentWindow() override;
+
   void ObserveVsync(VsyncObserver* aObserver) override;
   nsIWidget* RealWidget() override;
 
-private:
+ private:
   nsWindow* mWindow;
 };
 
-} // namespace widget
-} // namespace mozilla
+}  // namespace widget
+}  // namespace mozilla
 
-#endif // widget_windows_InProcessCompositorWidgetParent_h
+#endif  // widget_windows_InProcessCompositorWidgetParent_h
